@@ -3,6 +3,8 @@ from __future__ import annotations
 import inspect
 import logging
 import os
+import pdb  # noqa: T100
+import warnings
 from contextlib import (
     AbstractAsyncContextManager,
     AsyncExitStack,
@@ -14,23 +16,25 @@ from functools import partial
 from itertools import chain
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, AsyncGenerator, Callable, Iterable, Mapping, Sequence, TypedDict, cast
+from uuid import UUID
 
 from litestar._asgi import ASGIRouter
 from litestar._asgi.utils import get_route_handlers, wrap_in_exception_handler
 from litestar._openapi.plugin import OpenAPIPlugin
 from litestar._openapi.schema_generation import openapi_schema_plugins
 from litestar.config.allowed_hosts import AllowedHostsConfig
-from litestar.config.app import AppConfig
+from litestar.config.app import AppConfig, ExperimentalFeatures
 from litestar.config.response_cache import ResponseCacheConfig
 from litestar.connection import Request, WebSocket
 from litestar.datastructures.state import State
 from litestar.events.emitter import BaseEventEmitterBackend, SimpleEventEmitter
 from litestar.exceptions import (
+    LitestarWarning,
     MissingDependencyException,
     NoRouteMatchFoundException,
 )
 from litestar.logging.config import LoggingConfig, get_logger_placeholder
-from litestar.middleware.cors import CORSMiddleware
+from litestar.middleware._internal.cors import CORSMiddleware
 from litestar.openapi.config import OpenAPIConfig
 from litestar.plugins import (
     CLIPluginProtocol,
@@ -55,10 +59,10 @@ from litestar.utils.warnings import warn_pdb_on_exception
 if TYPE_CHECKING:
     from typing_extensions import Self
 
-    from litestar.config.app import ExperimentalFeatures
     from litestar.config.compression import CompressionConfig
     from litestar.config.cors import CORSConfig
     from litestar.config.csrf import CSRFConfig
+    from litestar.contrib.opentelemetry import OpenTelemetryPlugin
     from litestar.datastructures import CacheControlHeader, ETag
     from litestar.dto import AbstractDTO
     from litestar.events.listener import EventListener
@@ -77,6 +81,7 @@ if TYPE_CHECKING:
         BeforeMessageSendHookHandler,
         BeforeRequestHookHandler,
         ControllerRouterHandler,
+        Debugger,
         Dependencies,
         EmptyType,
         ExceptionHandlersMap,
@@ -101,7 +106,7 @@ if TYPE_CHECKING:
     from litestar.types.callable_types import LifespanHook
 
 
-__all__ = ("HandlerIndex", "Litestar", "DEFAULT_OPENAPI_CONFIG")
+__all__ = ("DEFAULT_OPENAPI_CONFIG", "HandlerIndex", "Litestar")
 
 DEFAULT_OPENAPI_CONFIG = OpenAPIConfig(title="Litestar API", version="1.0.0")
 """The default OpenAPI config used if not configuration is explicitly passed to the
@@ -134,12 +139,11 @@ class Litestar(Router):
     """
 
     __slots__ = (
-        "_lifespan_managers",
-        "_server_lifespan_managers",
         "_debug",
+        "_lifespan_managers",
         "_openapi_schema",
+        "_server_lifespan_managers",
         "_static_files_config",
-        "plugins",
         "after_exception",
         "allowed_hosts",
         "asgi_handler",
@@ -148,25 +152,23 @@ class Litestar(Router):
         "compression_config",
         "cors_config",
         "csrf_config",
+        "debugger_module",
         "event_emitter",
+        "experimental_features",
         "get_logger",
-        "include_in_schema",
         "logger",
         "logging_config",
         "multipart_form_part_limit",
         "on_shutdown",
         "on_startup",
         "openapi_config",
-        "request_class",
+        "pdb_on_exception",
+        "plugins",
         "response_cache_config",
         "route_map",
-        "signature_namespace",
         "state",
         "stores",
         "template_engine",
-        "websocket_class",
-        "pdb_on_exception",
-        "experimental_features",
     )
 
     def __init__(
@@ -201,8 +203,10 @@ class Litestar(Router):
         openapi_config: OpenAPIConfig | None = DEFAULT_OPENAPI_CONFIG,
         opt: Mapping[str, Any] | None = None,
         parameters: ParametersMap | None = None,
+        path: str | None = None,
         plugins: Sequence[PluginProtocol] | None = None,
         request_class: type[Request] | None = None,
+        request_max_body_size: int | None = 10_000_000,
         response_cache_config: ResponseCacheConfig | None = None,
         response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
@@ -222,6 +226,7 @@ class Litestar(Router):
         lifespan: Sequence[Callable[[Litestar], AbstractAsyncContextManager] | AbstractAsyncContextManager]
         | None = None,
         pdb_on_exception: bool | None = None,
+        debugger_module: Debugger = pdb,
         experimental_features: Iterable[ExperimentalFeatures] | None = None,
     ) -> None:
         """Initialize a ``Litestar`` application.
@@ -247,7 +252,7 @@ class Litestar(Router):
                 this app. Can be overridden by route handlers.
             compression_config: Configures compression behaviour of the application, this enabled a builtin or user
                 defined Compression middleware.
-            cors_config: If set, configures :class:`CORSMiddleware <.middleware.cors.CORSMiddleware>`.
+            cors_config: If set, configures CORS handling for the application.
             csrf_config: If set, configures :class:`CSRFMiddleware <.middleware.csrf.CSRFMiddleware>`.
             debug: If ``True``, app errors rendered as HTML with a stack trace.
             dependencies: A string keyed mapping of dependency :class:`Providers <.di.Provide>`.
@@ -280,9 +285,17 @@ class Litestar(Router):
                 :class:`ASGI Scope <.types.Scope>`.
             parameters: A mapping of :class:`Parameter <.params.Parameter>` definitions available to all application
                 paths.
+            path: A path fragment that is prefixed to all route handlers, controllers and routers associated
+                with the application instance.
+
+                .. versionadded:: 2.8.0
             pdb_on_exception: Drop into the PDB when an exception occurs.
+            debugger_module: A `pdb`-like debugger module that supports the `post_mortem()` protocol.
+                This module will be used when `pdb_on_exception` is set to True.
             plugins: Sequence of plugins.
             request_class: An optional subclass of :class:`Request <.connection.Request>` to use for http connections.
+            request_max_body_size: Maximum allowed size of the request body in bytes. If this size is exceeded, a
+                '413 - Request Entity Too Large' error response is returned.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as the app's default
                 response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>`.
@@ -353,10 +366,13 @@ class Litestar(Router):
             on_startup=list(on_startup or []),
             openapi_config=openapi_config,
             opt=dict(opt or {}),
+            path=path or "",
             parameters=parameters or {},
             pdb_on_exception=pdb_on_exception,
+            debugger_module=debugger_module,
             plugins=self._get_default_plugins(list(plugins or [])),
             request_class=request_class,
+            request_max_body_size=request_max_body_size,
             response_cache_config=response_cache_config or ResponseCacheConfig(),
             response_class=response_class,
             response_cookies=response_cookies or [],
@@ -382,8 +398,10 @@ class Litestar(Router):
         for handler in chain(
             on_app_init or [],
             (p.on_app_init for p in config.plugins if isinstance(p, InitPluginProtocol)),
+            [self._patch_opentelemetry_middleware],
         ):
             config = handler(config)  # pyright: ignore
+
         self.plugins = PluginRegistry(config.plugins)
 
         self._openapi_schema: OpenAPI | None = None
@@ -396,10 +414,19 @@ class Litestar(Router):
             self._lifespan_managers.append(store)
         self._server_lifespan_managers = [p.server_lifespan for p in config.plugins or [] if isinstance(p, CLIPlugin)]
         self.experimental_features = frozenset(config.experimental_features or [])
+        if ExperimentalFeatures.DTO_CODEGEN in self.experimental_features:
+            warnings.warn(
+                "Use of redundant experimental feature flag DTO_CODEGEN. "
+                "DTO codegen backend is enabled by default since Litestar 2.8. The "
+                "DTO_CODEGEN feature flag can be safely removed from the configuration "
+                "and will be removed in version 3.0.",
+                category=LitestarWarning,
+                stacklevel=2,
+            )
+
         self.get_logger: GetLogger = get_logger_placeholder
         self.logger: Logger | None = None
         self.routes: list[HTTPRoute | ASGIRoute | WebSocketRoute] = []
-        self.asgi_router = ASGIRouter(app=self)
 
         self.after_exception = [ensure_async_callable(h) for h in config.after_exception]
         self.allowed_hosts = cast("AllowedHostsConfig | None", config.allowed_hosts)
@@ -421,6 +448,7 @@ class Litestar(Router):
         self.websocket_class: type[WebSocket] = config.websocket_class or WebSocket
         self.debug = config.debug
         self.pdb_on_exception: bool = config.pdb_on_exception
+        self.debugger_module: Debugger = config.debugger_module
         self.include_in_schema = include_in_schema
 
         if self.pdb_on_exception:
@@ -429,12 +457,11 @@ class Litestar(Router):
         try:
             from starlette.exceptions import HTTPException as StarletteHTTPException
 
-            from litestar.middleware.exceptions.middleware import _starlette_exception_handler
+            from litestar.middleware._internal.exceptions.middleware import _starlette_exception_handler
 
             config.exception_handlers.setdefault(StarletteHTTPException, _starlette_exception_handler)
         except ImportError:
             pass
-
         super().__init__(
             after_request=config.after_request,
             after_response=config.after_response,
@@ -448,8 +475,9 @@ class Litestar(Router):
             middleware=config.middleware,
             opt=config.opt,
             parameters=config.parameters,
-            path="",
+            path=config.path,
             request_class=self.request_class,
+            request_max_body_size=request_max_body_size,
             response_class=config.response_class,
             response_cookies=config.response_cookies,
             response_headers=config.response_headers,
@@ -466,6 +494,8 @@ class Litestar(Router):
             websocket_class=self.websocket_class,
         )
 
+        self.asgi_router = ASGIRouter(app=self)
+
         for route_handler in config.route_handlers:
             self.register(route_handler)
 
@@ -478,6 +508,23 @@ class Litestar(Router):
 
         self.asgi_handler = self._create_asgi_handler()
 
+    @staticmethod
+    def _patch_opentelemetry_middleware(config: AppConfig) -> AppConfig:
+        # workaround to support otel middleware priority. Should be replaced by regular
+        # middleware priorities once available
+        try:
+            from litestar.contrib.opentelemetry import OpenTelemetryPlugin
+
+            if not any(isinstance(p, OpenTelemetryPlugin) for p in config.plugins):
+                config.middleware, otel_middleware = OpenTelemetryPlugin._pop_otel_middleware(config.middleware)
+                if otel_middleware:
+                    otel_plugin = OpenTelemetryPlugin()
+                    otel_plugin._middleware = otel_middleware
+                    config.plugins = [*config.plugins, otel_plugin]
+        except ImportError:
+            pass
+        return config
+
     @property
     @deprecated(version="2.6.0", kind="property", info="Use create_static_files router instead")
     def static_files_config(self) -> list[StaticFilesConfig]:
@@ -505,7 +552,7 @@ class Litestar(Router):
         plugins.append(MsgspecDIPlugin())
 
         with suppress(MissingDependencyException):
-            from litestar.contrib.pydantic import (
+            from litestar.plugins.pydantic import (
                 PydanticDIPlugin,
                 PydanticInitPlugin,
                 PydanticPlugin,
@@ -525,7 +572,7 @@ class Litestar(Router):
             if not pydantic_plugin_found and not pydantic_serialization_plugin_found:
                 plugins.append(PydanticDIPlugin())
         with suppress(MissingDependencyException):
-            from litestar.contrib.attrs import AttrsSchemaPlugin
+            from litestar.plugins.attrs import AttrsSchemaPlugin
 
             pre_configured = any(isinstance(plugin, AttrsSchemaPlugin) for plugin in plugins)
             if not pre_configured:
@@ -572,10 +619,15 @@ class Litestar(Router):
             await self.asgi_router.lifespan(receive=receive, send=send)  # type: ignore[arg-type]
             return
 
-        scope["app"] = self
+        scope["app"] = scope["litestar_app"] = self
         scope.setdefault("state", {})
         await self.asgi_handler(scope, receive, self._wrap_send(send=send, scope=scope))  # type: ignore[arg-type]
 
+    @classmethod
+    def from_scope(cls, scope: Scope) -> Litestar:
+        """Retrieve the Litestar application from the current ASGI scope"""
+        return scope["litestar_app"]
+
     async def _call_lifespan_hook(self, hook: LifespanHook) -> None:
         ret = hook(self) if inspect.signature(hook).parameters else hook()  # type: ignore[call-arg]
 
@@ -657,7 +709,8 @@ class Litestar(Router):
                 route.create_handler_map()
 
             elif isinstance(route, WebSocketRoute):
-                route.handler_parameter_model = route.create_handler_kwargs_model(route.route_handler)
+                handler = route.route_handler
+                route.handler_parameter_model = handler.create_kwargs_model(path_parameters=route.path_parameters)
 
             for plugin in self.plugins.receive_route:
                 plugin.receive_route(route)
@@ -724,7 +777,9 @@ class Litestar(Router):
 
         Args:
             name: A route handler unique name.
-            **path_parameters: Actual values for path parameters in the route.
+            **path_parameters: Actual values for path parameters in the route. Parameters of type
+                `datetime`, `date`, `time`, `timedelta`, `float`, `Path`, `UUID`
+                may be passed in their string representations.
 
         Raises:
             NoRouteMatchFoundException: If route with 'name' does not exist, path parameters are missing in
@@ -737,7 +792,7 @@ class Litestar(Router):
         if handler_index is None:
             raise NoRouteMatchFoundException(f"Route {name} can not be found")
 
-        allow_str_instead = {datetime, date, time, timedelta, float, Path}
+        allow_str_instead = {datetime, date, time, timedelta, float, Path, UUID}
         routes = sorted(
             self.asgi_router.route_mapping[handler_index["identifier"]],
             key=lambda r: len(r.path_parameters),
@@ -746,11 +801,7 @@ class Litestar(Router):
         passed_parameters = set(path_parameters.keys())
 
         selected_route = next(
-            (
-                route
-                for route in routes
-                if passed_parameters.issuperset({param.name for param in route.path_parameters})
-            ),
+            (route for route in routes if passed_parameters.issuperset(route.path_parameters)),
             routes[-1],
         )
         output: list[str] = []
@@ -810,7 +861,7 @@ class Litestar(Router):
         if not isinstance(handler_fn, StaticFiles):
             raise NoRouteMatchFoundException(f"Handler with name {name} is not a static files handler")
 
-        return join_paths([handler_index["paths"][0], file_path])  # type: ignore[unreachable]
+        return join_paths([handler_index["paths"][0], file_path])
 
     @property
     def route_handler_method_view(self) -> dict[str, list[str]]:
@@ -829,14 +880,18 @@ class Litestar(Router):
 
         If CORS or TrustedHost configs are provided to the constructor, they will wrap the router as well.
         """
-        asgi_handler: ASGIApp = self.asgi_router
+        asgi_handler = wrap_in_exception_handler(app=self.asgi_router)
+
         if self.cors_config:
             asgi_handler = CORSMiddleware(app=asgi_handler, config=self.cors_config)
 
-        return wrap_in_exception_handler(
-            app=asgi_handler,
-            exception_handlers=self.exception_handlers or {},  # pyright: ignore
-        )
+        try:
+            otel_plugin: OpenTelemetryPlugin = self.plugins.get("OpenTelemetryPlugin")
+            asgi_handler = otel_plugin.middleware(app=asgi_handler)
+        except KeyError:
+            pass
+
+        return asgi_handler
 
     def _wrap_send(self, send: Send, scope: Scope) -> Send:
         """Wrap the ASGI send and handles any 'before send' hooks.
@@ -864,7 +919,7 @@ class Litestar(Router):
         Returns:
             None
         """
-        self.plugins.get(OpenAPIPlugin)._build_openapi_schema()
+        self.plugins.get(OpenAPIPlugin)._build_openapi()
 
     def emit(self, event_id: str, *args: Any, **kwargs: Any) -> None:
         """Emit an event to all attached listeners.
