@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import enum
+import pdb  # noqa: T100
 from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Any, Callable
 
@@ -38,6 +39,7 @@ if TYPE_CHECKING:
         BeforeMessageSendHookHandler,
         BeforeRequestHookHandler,
         ControllerRouterHandler,
+        Debugger,
         ExceptionHandlersMap,
         Guard,
         Middleware,
@@ -151,12 +153,24 @@ class AppConfig:
     """
     parameters: ParametersMap = field(default_factory=dict)
     """A mapping of :class:`Parameter <.params.Parameter>` definitions available to all application paths."""
+    path: str = field(default="")
+    """A base path that prefixed to all route handlers, controllers and routers associated with the
+    application instance.
+
+    .. versionadded:: 2.8.0
+    """
     pdb_on_exception: bool = field(default=False)
     """Drop into the PDB on an exception"""
+    debugger_module: Debugger = field(default=pdb)
+    """A `pdb`-like debugger module that supports the `post_mortem()` protocol.
+    This module will be used when `pdb_on_exception` is set to True."""
     plugins: list[PluginProtocol] = field(default_factory=list)
     """List of :class:`SerializationPluginProtocol <.plugins.SerializationPluginProtocol>`."""
     request_class: type[Request] | None = field(default=None)
     """An optional subclass of :class:`Request <.connection.Request>` to use for http connections."""
+    request_max_body_size: int | None | EmptyType = Empty
+    """Maximum allowed size of the request body in bytes. If this size is exceeded, a '413 - Request Entity Too Large'
+    error response is returned."""
     response_class: type[Response] | None = field(default=None)
     """A custom subclass of :class:`Response <.response.Response>` to be used as the app's default response."""
     response_cookies: ResponseCookies = field(default_factory=list)
@@ -221,3 +235,6 @@ class AppConfig:
 
 class ExperimentalFeatures(str, enum.Enum):
     DTO_CODEGEN = "DTO_CODEGEN"
+    """Enable DTO codegen."""
+    FUTURE = "FUTURE"
+    """Enable future features that may be considered breaking or changing."""
