@@ -24,8 +24,6 @@ if TYPE_CHECKING:
 class OpenTelemetryInstrumentationMiddleware(AbstractMiddleware):
     """OpenTelemetry Middleware."""
 
-    __slots__ = ("open_telemetry_middleware",)
-
     def __init__(self, app: ASGIApp, config: OpenTelemetryConfig) -> None:
         """Middleware that adds OpenTelemetry instrumentation to the application.
 
@@ -36,8 +34,8 @@ class OpenTelemetryInstrumentationMiddleware(AbstractMiddleware):
         super().__init__(app=app, scopes=config.scopes, exclude=config.exclude, exclude_opt_key=config.exclude_opt_key)
         self.open_telemetry_middleware = OpenTelemetryMiddleware(
             app=app,
-            client_request_hook=config.client_request_hook_handler,
-            client_response_hook=config.client_response_hook_handler,
+            client_request_hook=config.client_request_hook_handler,  # type: ignore[arg-type]
+            client_response_hook=config.client_response_hook_handler,  # type: ignore[arg-type]
             default_span_details=config.scope_span_details_extractor,
             excluded_urls=get_excluded_urls(config.exclude_urls_env_key),
             meter=config.meter,
@@ -57,4 +55,4 @@ class OpenTelemetryInstrumentationMiddleware(AbstractMiddleware):
         Returns:
             None
         """
-        await self.open_telemetry_middleware(scope, receive, send)
+        await self.open_telemetry_middleware(scope, receive, send)  # type: ignore[arg-type] # pyright: ignore[reportGeneralTypeIssues]
