@@ -12,7 +12,7 @@ from litestar.handlers.base import BaseRouteHandler
 from litestar.handlers.http_handlers import HTTPRouteHandler
 from litestar.handlers.websocket_handlers import WebsocketRouteHandler
 from litestar.types.empty import Empty
-from litestar.utils import ensure_async_callable, normalize_path
+from litestar.utils import normalize_path
 from litestar.utils.signature import add_types_to_signature_namespace
 
 __all__ = ("Controller",)
@@ -51,6 +51,7 @@ class Controller:
         "after_request",
         "after_response",
         "before_request",
+        "cache_control",
         "dependencies",
         "dto",
         "etag",
@@ -63,15 +64,17 @@ class Controller:
         "parameters",
         "path",
         "request_class",
+        "request_max_body_size",
         "response_class",
         "response_cookies",
         "response_headers",
         "return_dto",
         "security",
         "signature_namespace",
+        "signature_types",
         "tags",
-        "type_encoders",
         "type_decoders",
+        "type_encoders",
         "websocket_class",
     )
 
@@ -134,6 +137,11 @@ class Controller:
     """A custom subclass of :class:`Request <.connection.Request>` to be used as the default request for all route
     handlers under the controller.
     """
+    request_max_body_size: int | None | EmptyType
+    """
+    Maximum allowed size of the request body in bytes. If this size is exceeded, a '413 - Request Entity Too Large'
+    error response is returned."""
+
     response_class: type[Response] | None
     """A custom subclass of :class:`Response <.response.Response>` to be used as the default response for all route
     handlers under the controller.
@@ -174,12 +182,11 @@ class Controller:
         Args:
             owner: An instance of :class:`Router <.router.Router>`
         """
-        # Since functions set on classes are bound, we need replace the bound instance with the class version and wrap
-        # it to ensure it does not get bound.
+        # Since functions set on classes are bound, we need replace the bound instance with the class version
         for key in ("after_request", "after_response", "before_request"):
             cls_value = getattr(type(self), key, None)
             if callable(cls_value):
-                setattr(self, key, ensure_async_callable(cls_value))
+                setattr(self, key, cls_value)
 
         if not hasattr(self, "dto"):
             self.dto = Empty
@@ -190,6 +197,9 @@ class Controller:
         if not hasattr(self, "include_in_schema"):
             self.include_in_schema = Empty
 
+        if not hasattr(self, "request_max_body_size"):
+            self.request_max_body_size = Empty
+
         self.signature_namespace = add_types_to_signature_namespace(
             getattr(self, "signature_types", []), getattr(self, "signature_namespace", {})
         )
@@ -203,6 +213,42 @@ class Controller:
         self.path = normalize_path(self.path or "/")
         self.owner = owner
 
+    def as_router(self) -> Router:
+        from litestar.router import Router
+
+        router = Router(
+            path=self.path,
+            route_handlers=self.get_route_handlers(),
+            after_request=self.after_request,
+            after_response=self.after_response,
+            before_request=self.before_request,
+            cache_control=self.cache_control,
+            dependencies=self.dependencies,
+            dto=self.dto,
+            etag=self.etag,
+            exception_handlers=self.exception_handlers,
+            guards=self.guards,
+            include_in_schema=self.include_in_schema,
+            middleware=self.middleware,
+            opt=self.opt,
+            parameters=self.parameters,
+            request_class=self.request_class,
+            response_class=self.response_class,
+            response_cookies=self.response_cookies,
+            response_headers=self.response_headers,
+            return_dto=self.return_dto,
+            security=self.security,
+            signature_types=self.signature_types,
+            signature_namespace=self.signature_namespace,
+            tags=self.tags,
+            type_encoders=self.type_encoders,
+            type_decoders=self.type_decoders,
+            websocket_class=self.websocket_class,
+            request_max_body_size=self.request_max_body_size,
+        )
+        router.owner = self.owner
+        return router
+
     def get_route_handlers(self) -> list[BaseRouteHandler]:
         """Get a controller's route handlers and set the controller as the handlers' owner.
 
