@@ -1,6 +1,7 @@
 """DTO backends do the heavy lifting of decoding and validating raw bytes into domain models, and
 back again, to bytes.
 """
+
 from __future__ import annotations
 
 import re
@@ -23,6 +24,7 @@ from litestar.dto._backend import DTOBackend
 from litestar.dto._types import (
     CollectionType,
     CompositeType,
+    MappingType,
     SimpleType,
     TransferDTOFieldDefinition,
     TransferType,
@@ -41,11 +43,11 @@ __all__ = ("DTOCodegenBackend",)
 
 class DTOCodegenBackend(DTOBackend):
     __slots__ = (
-        "_transfer_to_dict",
-        "_transfer_to_model_type",
+        "_encode_data",
         "_transfer_data_from_builtins",
         "_transfer_data_from_builtins_with_overrides",
-        "_encode_data",
+        "_transfer_to_dict",
+        "_transfer_to_model_type",
     )
 
     def __init__(
@@ -182,8 +184,7 @@ class DTOCodegenBackend(DTOBackend):
 
 
 class FieldAccessManager(Protocol):
-    def __call__(self, source_name: str, field_name: str, expect_optional: bool) -> ContextManager[str]:
-        ...
+    def __call__(self, source_name: str, field_name: str, expect_optional: bool) -> ContextManager[str]: ...
 
 
 class TransferFunctionFactory:
@@ -506,6 +507,21 @@ class TransferFunctionFactory:
             self._add_stmt(f"{assignment_target} = {origin_name}({source_value_name})")
             return
 
+        if isinstance(transfer_type, MappingType):
+            origin_name = self._add_to_fn_globals("origin", transfer_type.field_definition.instantiable_origin)
+            if transfer_type.has_nested:
+                transfer_type_data_fn = TransferFunctionFactory.create_transfer_type_data(
+                    is_data_field=self.is_data_field, transfer_type=transfer_type.value_type
+                )
+                transfer_type_data_name = self._add_to_fn_globals("transfer_type_data", transfer_type_data_fn)
+                self._add_stmt(
+                    f"{assignment_target} = {origin_name}((key, {transfer_type_data_name}(item)) for key, item in {source_value_name}.items())"
+                )
+                return
+
+            self._add_stmt(f"{assignment_target} = {origin_name}({source_value_name})")
+            return
+
         self._add_stmt(f"{assignment_target} = {source_value_name}")
 
     def _create_transfer_nested_union_type_data(
