@@ -2,15 +2,15 @@ from __future__ import annotations
 
 import sys
 from abc import ABC, abstractmethod
-from dataclasses import asdict, dataclass, field
+from dataclasses import dataclass, field, fields
 from importlib.util import find_spec
 from logging import INFO
 from typing import TYPE_CHECKING, Any, Callable, Literal, cast
 
 from litestar.exceptions import ImproperlyConfiguredException, MissingDependencyException
-from litestar.serialization import encode_json
 from litestar.serialization.msgspec_hooks import _msgspec_json_encoder
-from litestar.utils.deprecation import deprecated
+from litestar.utils.dataclass import simple_asdict
+from litestar.utils.deprecation import deprecated, warn_deprecation
 
 __all__ = ("BaseLoggingConfig", "LoggingConfig", "StructLoggingConfig")
 
@@ -27,14 +27,6 @@ if TYPE_CHECKING:
     from litestar.types.callable_types import ExceptionLoggingHandler, GetLogger
 
 
-try:
-    from structlog.types import BindableLogger, Processor, WrappedLogger
-except ImportError:
-    BindableLogger = Any  # type: ignore[assignment, misc]
-    Processor = Any  # type: ignore[misc]
-    WrappedLogger = Any  # type: ignore[misc]
-
-
 default_handlers: dict[str, dict[str, Any]] = {
     "console": {
         "class": "logging.StreamHandler",
@@ -49,7 +41,20 @@ default_handlers: dict[str, dict[str, Any]] = {
 }
 
 if sys.version_info >= (3, 12, 0):
-    default_handlers["queue_listener"]["handlers"] = ["console"]
+    default_handlers["queue_listener"].update(
+        {
+            "class": "logging.handlers.QueueHandler",
+            "queue": {
+                "()": "queue.Queue",
+                "maxsize": -1,
+            },
+            "listener": "litestar.logging.standard.LoggingQueueListener",
+            "handlers": ["console"],
+        }
+    )
+
+    # do not format twice, the console handler will do the job
+    del default_handlers["queue_listener"]["formatter"]
 
 
 default_picologging_handlers: dict[str, dict[str, Any]] = {
@@ -66,6 +71,18 @@ default_picologging_handlers: dict[str, dict[str, Any]] = {
 }
 
 
+def _get_default_formatters() -> dict[str, dict[str, Any]]:
+    return {
+        "standard": {"format": "%(levelname)s - %(asctime)s - %(name)s - %(module)s - %(message)s"},
+    }
+
+
+def _get_default_loggers() -> dict[str, dict[str, Any]]:
+    return {
+        "litestar": {"level": "INFO", "handlers": ["queue_listener"], "propagate": False},
+    }
+
+
 def get_logger_placeholder(_: str | None = None) -> NoReturn:
     """Raise: An :class:`ImproperlyConfiguredException <.exceptions.ImproperlyConfiguredException>`"""
     raise ImproperlyConfiguredException(
@@ -73,46 +90,63 @@ def get_logger_placeholder(_: str | None = None) -> NoReturn:
     )
 
 
-def _get_default_handlers() -> dict[str, dict[str, Any]]:
+def _get_default_logging_module() -> str:
+    if find_spec("picologging"):
+        return "picologging"
+    return "logging"
+
+
+def _get_default_handlers(logging_module: str) -> dict[str, dict[str, Any]]:
     """Return the default logging handlers for the config.
 
     Returns:
         A dictionary of logging handlers
     """
-    if find_spec("picologging"):
+    if logging_module == "picologging":
         return default_picologging_handlers
     return default_handlers
 
 
 def _default_exception_logging_handler_factory(
-    is_struct_logger: bool, traceback_line_limit: int
+    is_struct_logger: bool,
+    traceback_line_limit: int,
 ) -> ExceptionLoggingHandler:
     """Create an exception logging handler function.
 
     Args:
         is_struct_logger: Whether the logger is a structlog instance.
         traceback_line_limit: Maximal number of lines to log from the
-            traceback.
+            traceback. This parameter is deprecated and ignored.
 
     Returns:
         An exception logging handler.
     """
 
-    def _default_exception_logging_handler(logger: Logger, scope: Scope, tb: list[str]) -> None:
-        # we limit the length of the stack trace to 20 lines.
-        first_line = tb.pop(0)
+    if traceback_line_limit != -1:
+        warn_deprecation(
+            version="2.9.0",
+            deprecated_name="traceback_line_limit",
+            kind="parameter",
+            info="The value is ignored. Use a custom 'exception_logging_handler' instead.",
+            removal_in="3.0",
+        )
 
-        if is_struct_logger:
+    if is_struct_logger:
+
+        def _default_exception_logging_handler(logger: Logger, scope: Scope, tb: list[str]) -> None:
             logger.exception(
-                "Uncaught Exception",
+                "Uncaught exception",
                 connection_type=scope["type"],
                 path=scope["path"],
-                traceback="".join(tb[-traceback_line_limit:]),
             )
-        else:
-            stack_trace = first_line + "".join(tb[-traceback_line_limit:])
+
+    else:
+
+        def _default_exception_logging_handler(logger: Logger, scope: Scope, tb: list[str]) -> None:
             logger.exception(
-                "exception raised on %s connection to route %s\n\n%s", scope["type"], scope["path"], stack_trace
+                "Uncaught exception (connection_type=%s, path=%s):",
+                scope["type"],
+                scope["path"],
             )
 
     return _default_exception_logging_handler
@@ -121,12 +155,16 @@ def _default_exception_logging_handler_factory(
 class BaseLoggingConfig(ABC):
     """Abstract class that should be extended by logging configs."""
 
-    __slots__ = ("log_exceptions", "traceback_line_limit", "exception_logging_handler")
+    __slots__ = ("exception_logging_handler", "log_exceptions", "traceback_line_limit")
 
     log_exceptions: Literal["always", "debug", "never"]
     """Should exceptions be logged, defaults to log exceptions when ``app.debug == True``'"""
     traceback_line_limit: int
-    """Max number of lines to print for exception traceback"""
+    """Max number of lines to print for exception traceback.
+
+    .. deprecated:: 2.9.0
+        This parameter is deprecated and ignored. It will be removed in a future release.
+    """
     exception_logging_handler: ExceptionLoggingHandler | None
     """Handler function for logging exceptions."""
 
@@ -147,12 +185,11 @@ class BaseLoggingConfig(ABC):
 
 @dataclass
 class LoggingConfig(BaseLoggingConfig):
-    """Configuration class for standard logging.
-
-    Notes:
-        - If 'picologging' is installed it will be used by default.
-    """
+    """Configuration class for standard logging."""
 
+    logging_module: str = field(default_factory=_get_default_logging_module)
+    """Logging module. ``logging`` and ``picologging`` are supported. ``picologging`` will be used by default if
+    installed."""
     version: Literal[1] = field(default=1)
     """The only valid value at present is 1."""
     incremental: bool = field(default=False)
@@ -164,27 +201,34 @@ class LoggingConfig(BaseLoggingConfig):
     disable_existing_loggers: bool = field(default=False)
     """Whether any existing non-root loggers are to be disabled."""
     filters: dict[str, dict[str, Any]] | None = field(default=None)
-    """A dict in which each key is a filter id and each value is a dict describing how to configure the corresponding
-    Filter instance.
+    """A dict in which each key is a filter id and each value is a dict describing how to configure the
+    corresponding Filter_ instance.
+
+    .. _Filter: https://docs.python.org/3/library/logging.html#filter-objects
     """
     propagate: bool = field(default=True)
-    """If messages must propagate to handlers higher up the logger hierarchy from this logger."""
-    formatters: dict[str, dict[str, Any]] = field(
-        default_factory=lambda: {
-            "standard": {"format": "%(levelname)s - %(asctime)s - %(name)s - %(module)s - %(message)s"}
-        }
-    )
-    handlers: dict[str, dict[str, Any]] = field(default_factory=_get_default_handlers)
-    """A dict in which each key is a handler id and each value is a dict describing how to configure the corresponding
-    Handler instance.
+    """If messages must propagate to handlers higher up the logger hierarchy from this logger.
+
+    .. deprecated:: 2.10.0
+        This parameter is deprecated. It will be removed in a future release. Use ``propagate`` at the logger level.
     """
-    loggers: dict[str, dict[str, Any]] = field(
-        default_factory=lambda: {
-            "litestar": {"level": "INFO", "handlers": ["queue_listener"], "propagate": False},
-        }
-    )
-    """A dict in which each key is a logger name and each value is a dict describing how to configure the corresponding
-    Logger instance.
+    formatters: dict[str, dict[str, Any]] = field(default_factory=_get_default_formatters)
+    """A dict in which each key is a formatter and each value is a dict describing how to configure the
+    corresponding Formatter_ instance. A ``standard`` formatter is provided.
+
+    .. _Formatter: https://docs.python.org/3/library/logging.html#formatter-objects
+    """
+    handlers: dict[str, dict[str, Any]] = field(default_factory=dict)
+    """A dict in which each key is a handler id and each value is a dict describing how to configure the
+    corresponding Handler_ instance. Two handlers are provided, ``console`` and ``queue_listener``.
+
+    .. _Handler: https://docs.python.org/3/library/logging.html#handler-objects
+    """
+    loggers: dict[str, dict[str, Any]] = field(default_factory=_get_default_loggers)
+    """A dict in which each key is a logger name and each value is a dict describing how to configure the
+    corresponding Logger_ instance. A ``litestar`` logger is mandatory and will be configured as required.
+
+    .. _Logger: https://docs.python.org/3/library/logging.html#logger-objects
     """
     root: dict[str, dict[str, Any] | list[Any] | str] = field(
         default_factory=lambda: {
@@ -200,21 +244,27 @@ class LoggingConfig(BaseLoggingConfig):
     """Should the root logger be configured, defaults to True for ease of configuration."""
     log_exceptions: Literal["always", "debug", "never"] = field(default="debug")
     """Should exceptions be logged, defaults to log exceptions when 'app.debug == True'"""
-    traceback_line_limit: int = field(default=20)
-    """Max number of lines to print for exception traceback"""
+    traceback_line_limit: int = field(default=-1)
+    """Max number of lines to print for exception traceback.
+
+    .. deprecated:: 2.9.0
+        This parameter is deprecated and ignored. It will be removed in a future release.
+    """
     exception_logging_handler: ExceptionLoggingHandler | None = field(default=None)
     """Handler function for logging exceptions."""
 
     def __post_init__(self) -> None:
+        if "standard" not in self.formatters:
+            self.formatters["standard"] = _get_default_formatters()["standard"]
+
+        if "console" not in self.handlers:
+            self.handlers["console"] = _get_default_handlers(self.logging_module)["console"]
+
         if "queue_listener" not in self.handlers:
-            self.handlers["queue_listener"] = _get_default_handlers()["queue_listener"]
+            self.handlers["queue_listener"] = _get_default_handlers(self.logging_module)["queue_listener"]
 
         if "litestar" not in self.loggers:
-            self.loggers["litestar"] = {
-                "level": "INFO",
-                "handlers": ["queue_listener"],
-                "propagate": False,
-            }
+            self.loggers["litestar"] = _get_default_loggers()["litestar"]
 
         if self.log_exceptions != "never" and self.exception_logging_handler is None:
             self.exception_logging_handler = _default_exception_logging_handler_factory(
@@ -228,23 +278,37 @@ class LoggingConfig(BaseLoggingConfig):
             A 'logging.getLogger' like function.
         """
 
-        if "picologging" in str(encode_json(self.handlers)):
+        excluded_fields: set[str] = {
+            "logging_module",
+            "configure_root_logger",
+            "exception_logging_handler",
+            "log_exceptions",
+            "propagate",
+            "traceback_line_limit",
+        }
+
+        if not self.configure_root_logger:
+            excluded_fields.add("root")
+
+        if self.logging_module == "picologging":
             try:
-                from picologging import config, getLogger
+                from picologging import (  # pyright: ignore[reportMissingImports,reportGeneralTypeIssues]
+                    config,  # pyright: ignore[reportMissingImports,reportGeneralTypeIssues]
+                    getLogger,  # pyright: ignore[reportMissingImports,reportGeneralTypeIssues]
+                )
             except ImportError as e:
                 raise MissingDependencyException("picologging") from e
 
-            values = {
-                k: v
-                for k, v in asdict(self).items()
-                if v is not None and k not in ("incremental", "configure_root_logger")
-            }
+            excluded_fields.add("incremental")
         else:
-            from logging import config, getLogger  # type: ignore[no-redef, assignment]
+            from logging import config, getLogger  # type: ignore[no-redef,assignment,unused-ignore]
+
+        values = {
+            _field.name: getattr(self, _field.name)
+            for _field in fields(self)
+            if getattr(self, _field.name) is not None and _field.name not in excluded_fields
+        }
 
-            values = {k: v for k, v in asdict(self).items() if v is not None and k not in ("configure_root_logger",)}
-        if not self.configure_root_logger:
-            values.pop("root")
         config.dictConfig(values)
         return cast("Callable[[str], Logger]", getLogger)
 
@@ -305,7 +369,9 @@ def stdlib_json_serializer(value: EventDict, **_: Any) -> str:  # pragma: no cov
     return _msgspec_json_encoder.encode(value).decode("utf-8")
 
 
-def default_structlog_processors(as_json: bool = True) -> list[Processor]:  # pyright: ignore
+def default_structlog_processors(
+    as_json: bool = True, json_serializer: Callable[[Any], Any] = default_json_serializer
+) -> list[Processor]:  # pyright: ignore
     """Set the default processors for structlog.
 
     Returns:
@@ -321,7 +387,7 @@ def default_structlog_processors(as_json: bool = True) -> list[Processor]:  # py
                 structlog.processors.add_log_level,
                 structlog.processors.format_exc_info,
                 structlog.processors.TimeStamper(fmt="iso"),
-                structlog.processors.JSONRenderer(serializer=default_json_serializer),
+                structlog.processors.JSONRenderer(serializer=json_serializer),
             ]
         return [
             structlog.contextvars.merge_contextvars,
@@ -410,8 +476,12 @@ class StructLoggingConfig(BaseLoggingConfig):
     """Whether to cache the logger configuration and reuse."""
     log_exceptions: Literal["always", "debug", "never"] = field(default="debug")
     """Should exceptions be logged, defaults to log exceptions when 'app.debug == True'"""
-    traceback_line_limit: int = field(default=20)
-    """Max number of lines to print for exception traceback"""
+    traceback_line_limit: int = field(default=-1)
+    """Max number of lines to print for exception traceback.
+
+    .. deprecated:: 2.9.0
+        This parameter is deprecated and ignored. It will be removed in a future release.
+    """
     exception_logging_handler: ExceptionLoggingHandler | None = field(default=None)
     """Handler function for logging exceptions."""
     pretty_print_tty: bool = field(default=True)
@@ -419,9 +489,9 @@ class StructLoggingConfig(BaseLoggingConfig):
 
     def __post_init__(self) -> None:
         if self.processors is None:
-            self.processors = default_structlog_processors(not sys.stderr.isatty() and self.pretty_print_tty)
+            self.processors = default_structlog_processors(as_json=self.as_json())
         if self.logger_factory is None:
-            self.logger_factory = default_logger_factory(not sys.stderr.isatty() and self.pretty_print_tty)
+            self.logger_factory = default_logger_factory(as_json=self.as_json())
         if self.log_exceptions != "never" and self.exception_logging_handler is None:
             self.exception_logging_handler = _default_exception_logging_handler_factory(
                 is_struct_logger=True, traceback_line_limit=self.traceback_line_limit
@@ -434,15 +504,16 @@ class StructLoggingConfig(BaseLoggingConfig):
                     formatters={
                         "standard": {
                             "()": structlog.stdlib.ProcessorFormatter,
-                            "processors": default_structlog_standard_lib_processors(
-                                as_json=not sys.stderr.isatty() and self.pretty_print_tty
-                            ),
+                            "processors": default_structlog_standard_lib_processors(as_json=self.as_json()),
                         }
                     }
                 )
         except ImportError:
             self.standard_lib_logging_config = LoggingConfig()
 
+    def as_json(self) -> bool:
+        return not (sys.stderr.isatty() and self.pretty_print_tty)
+
     def configure(self) -> GetLogger:
         """Return logger with the given configuration.
 
@@ -457,7 +528,7 @@ class StructLoggingConfig(BaseLoggingConfig):
         structlog.configure(
             **{
                 k: v
-                for k, v in asdict(self).items()
+                for k, v in simple_asdict(self).items()
                 if k
                 not in (
                     "standard_lib_logging_config",
