@@ -11,15 +11,15 @@ __all__ = ("QueueListenerHandler",)
 
 
 try:
-    import picologging  # noqa: F401
+    import picologging  # noqa: F401 # pyright: ignore[reportMissingImports]
 except ImportError as e:
     raise MissingDependencyException("picologging") from e
 
-from picologging import StreamHandler
-from picologging.handlers import QueueHandler, QueueListener
+from picologging import StreamHandler  # pyright: ignore[reportMissingImports]
+from picologging.handlers import QueueHandler, QueueListener  # pyright: ignore[reportMissingImports]
 
 
-class QueueListenerHandler(QueueHandler):
+class QueueListenerHandler(QueueHandler):  # type: ignore[misc,unused-ignore]
     """Configure queue listener and handler to support non-blocking logging configuration."""
 
     def __init__(self, handlers: list[Any] | None = None) -> None:
@@ -32,8 +32,8 @@ class QueueListenerHandler(QueueHandler):
             - Requires ``picologging`` to be installed.
         """
         super().__init__(Queue(-1))
-        handlers = resolve_handlers(handlers) if handlers else [StreamHandler()]
-        self.listener = QueueListener(self.queue, *handlers)
+        handlers = resolve_handlers(handlers) if handlers else [StreamHandler()]  # pyright: ignore[reportGeneralTypeIssues]
+        self.listener = QueueListener(self.queue, *handlers)  # pyright: ignore[reportGeneralTypeIssues]
         self.listener.start()
 
         atexit.register(self.listener.stop)
