@@ -1,27 +1,31 @@
 from __future__ import annotations
 
 from functools import cached_property
-from typing import TYPE_CHECKING, Any, Callable, Literal
-
-from yaml import dump as dump_yaml
+from typing import TYPE_CHECKING, Any, Callable, Final, Literal
+from uuid import uuid4
 
 from litestar.constants import OPENAPI_NOT_INITIALIZED
 from litestar.controller import Controller
 from litestar.enums import MediaType, OpenAPIMediaType
 from litestar.exceptions import ImproperlyConfiguredException
 from litestar.handlers import get
+from litestar.openapi.config import _DEFAULT_SCHEMA_SITE
 from litestar.response.base import ASGIResponse
 from litestar.serialization import encode_json
 from litestar.serialization.msgspec_hooks import decode_json
 from litestar.status_codes import HTTP_404_NOT_FOUND
 
-__all__ = ("OpenAPIController",)
-
-
 if TYPE_CHECKING:
     from litestar.connection.request import Request
     from litestar.openapi.spec.open_api import OpenAPI
 
+__all__ = ("OpenAPIController",)
+
+# NOTE: We are explicitly using a different name to the one defined in litestar.constants so that an openapi
+#   controller can be added to a router on the same application as the openapi router.
+#   See: https://github.com/litestar-org/litestar/issues/3337
+OPENAPI_JSON_HANDLER_NAME: Final = f"{uuid4().hex}_litestar_openapi_json"
+
 
 class OpenAPIController(Controller):
     """Controller for OpenAPI endpoints."""
@@ -32,7 +36,7 @@ class OpenAPIController(Controller):
     """Base styling of the html body."""
     redoc_version: str = "next"
     """Redoc version to download from the CDN."""
-    swagger_ui_version: str = "5.1.3"
+    swagger_ui_version: str = "5.18.2"
     """SwaggerUI version to download from the CDN."""
     stoplight_elements_version: str = "7.7.18"
     """StopLight Elements version to download from the CDN."""
@@ -116,11 +120,13 @@ class OpenAPIController(Controller):
         root_path = set(filter(None, self.path.split("/")))
 
         config = request.app.openapi_config
+        enabled_endpoints = config.enabled_endpoints or set()
+        root_schema_site = config.root_schema_site or _DEFAULT_SCHEMA_SITE
 
-        if request_path == root_path and config.root_schema_site in config.enabled_endpoints:
+        if request_path == root_path and root_schema_site in enabled_endpoints:
             return True
 
-        return bool(request_path & config.enabled_endpoints)
+        return bool(request_path & enabled_endpoints)
 
     @property
     def favicon(self) -> str:
@@ -163,15 +169,23 @@ class OpenAPIController(Controller):
         Returns:
             A Response instance with the YAML object rendered into a string.
         """
+        from yaml import dump as dump_yaml
+
         if self.should_serve_endpoint(request):
-            if not self._dumped_json_schema:
+            if not self._dumped_yaml_schema:
                 schema_json = decode_json(self._get_schema_as_json(request))
                 schema_yaml = dump_yaml(schema_json, default_flow_style=False)
                 self._dumped_yaml_schema = schema_yaml.encode("utf-8")
             return ASGIResponse(body=self._dumped_yaml_schema, media_type=OpenAPIMediaType.OPENAPI_YAML)
         return ASGIResponse(body=b"", status_code=HTTP_404_NOT_FOUND, media_type=MediaType.HTML)
 
-    @get(path="/openapi.json", media_type=OpenAPIMediaType.OPENAPI_JSON, include_in_schema=False, sync_to_thread=False)
+    @get(
+        path="/openapi.json",
+        media_type=OpenAPIMediaType.OPENAPI_JSON,
+        include_in_schema=False,
+        sync_to_thread=False,
+        name=OPENAPI_JSON_HANDLER_NAME,
+    )
     def retrieve_schema_json(self, request: Request[Any, Any, Any]) -> ASGIResponse:
         """Return the OpenAPI schema as JSON with an ``application/vnd.oai.openapi+json`` Content-Type header.
 
@@ -210,7 +224,7 @@ class OpenAPIController(Controller):
         if not config:  # pragma: no cover
             raise ImproperlyConfiguredException(OPENAPI_NOT_INITIALIZED)
 
-        render_method = self.render_methods_map[config.root_schema_site]
+        render_method = self.render_methods_map[config.root_schema_site or _DEFAULT_SCHEMA_SITE]
 
         if self.should_serve_endpoint(request):
             return ASGIResponse(body=render_method(request), media_type=MediaType.HTML)
@@ -457,10 +471,10 @@ class OpenAPIController(Controller):
           </head>
         """
 
-        body = """
+        body = f"""
           <body>
             <elements-api
-                apiDescriptionUrl="openapi.json"
+                apiDescriptionUrl="{request.app.route_reverse(OPENAPI_JSON_HANDLER_NAME)}"
                 router="hash"
                 layout="sidebar"
             />
@@ -489,9 +503,9 @@ class OpenAPIController(Controller):
           </head>
         """
 
-        body = """
+        body = f"""
           <body>
-            <rapi-doc spec-url="openapi.json" />
+            <rapi-doc spec-url="{request.app.route_reverse(OPENAPI_JSON_HANDLER_NAME)}" />
           </body>
         """
 
