@@ -2,22 +2,26 @@ from litestar.plugins.base import (
     CLIPlugin,
     CLIPluginProtocol,
     DIPlugin,
+    InitPlugin,
     InitPluginProtocol,
     OpenAPISchemaPlugin,
     OpenAPISchemaPluginProtocol,
     PluginProtocol,
     PluginRegistry,
+    SerializationPlugin,
     SerializationPluginProtocol,
 )
 
 __all__ = (
-    "SerializationPluginProtocol",
-    "DIPlugin",
     "CLIPlugin",
-    "InitPluginProtocol",
-    "OpenAPISchemaPluginProtocol",
-    "OpenAPISchemaPlugin",
-    "PluginProtocol",
     "CLIPluginProtocol",
+    "DIPlugin",
+    "InitPlugin",
+    "InitPluginProtocol",
+    "OpenAPISchemaPlugin",
+    "OpenAPISchemaPluginProtocol",
+    "PluginProtocol",
     "PluginRegistry",
+    "SerializationPlugin",
+    "SerializationPluginProtocol",
 )
