@@ -19,8 +19,10 @@ from uuid import UUID
 
 import msgspec
 
+from litestar.datastructures.secret_values import SecretBytes, SecretString
 from litestar.exceptions import SerializationException
 from litestar.types import Empty, EmptyType, Serializer, TypeDecodersSequence
+from litestar.utils.typing import get_origin_or_inner_type
 
 if TYPE_CHECKING:
     from litestar.types import TypeEncodersMap
@@ -52,6 +54,8 @@ DEFAULT_TYPE_ENCODERS: TypeEncodersMap = {
     deque: list,
     Decimal: lambda val: int(val) if val.as_tuple().exponent >= 0 else float(val),
     Pattern: lambda val: val.pattern,
+    SecretBytes: lambda val: val.get_obscured().decode("utf-8"),
+    SecretString: lambda val: val.get_obscured(),
     # support subclasses of stdlib types, If no previous type matched, these will be
     # the last type in the mro, so we use this to (attempt to) convert a subclass into
     # its base class. # see https://github.com/jcrist/msgspec/issues/248
@@ -104,8 +108,19 @@ def default_deserializer(
 
     from litestar.datastructures.state import ImmutableState
 
-    if isinstance(value, target_type):
-        return value
+    try:
+        if isinstance(value, target_type):
+            return value
+    except TypeError as exc:
+        # we might get a TypeError here if target_type is a subscribed generic. For
+        # performance reasons, we let this happen and only unwrap this when we're
+        # certain this might be the case
+        if (origin := get_origin_or_inner_type(target_type)) is not None:
+            target_type = origin
+            if isinstance(value, target_type):
+                return value
+        else:
+            raise exc
 
     if type_decoders:
         for predicate, decoder in type_decoders:
@@ -115,6 +130,12 @@ def default_deserializer(
     if issubclass(target_type, (Path, PurePath, ImmutableState, UUID)):
         return target_type(value)
 
+    if issubclass(target_type, SecretBytes) and isinstance(value, (bytes, str)):
+        return SecretBytes(value.encode("utf-8") if isinstance(value, str) else value)
+
+    if issubclass(target_type, SecretString) and isinstance(value, str):
+        return SecretString(value)
+
     raise TypeError(f"Unsupported type: {type(value)!r}")
 
 
@@ -144,29 +165,28 @@ def encode_json(value: Any, serializer: Callable[[Any], Any] | None = None) -> b
 
 
 @overload
-def decode_json(value: str | bytes) -> Any:
-    ...
+def decode_json(value: str | bytes, strict: bool = ...) -> Any: ...
 
 
 @overload
-def decode_json(value: str | bytes, type_decoders: TypeDecodersSequence | None) -> Any:
-    ...
+def decode_json(value: str | bytes, type_decoders: TypeDecodersSequence | None, strict: bool = ...) -> Any: ...
 
 
 @overload
-def decode_json(value: str | bytes, target_type: type[T]) -> T:
-    ...
+def decode_json(value: str | bytes, target_type: type[T], strict: bool = ...) -> T: ...
 
 
 @overload
-def decode_json(value: str | bytes, target_type: type[T], type_decoders: TypeDecodersSequence | None) -> T:
-    ...
+def decode_json(
+    value: str | bytes, target_type: type[T], type_decoders: TypeDecodersSequence | None, strict: bool = ...
+) -> T: ...
 
 
 def decode_json(  # type: ignore[misc]
     value: str | bytes,
     target_type: type[T] | EmptyType = Empty,  # pyright: ignore
     type_decoders: TypeDecodersSequence | None = None,
+    strict: bool = True,
 ) -> Any:
     """Decode a JSON string/bytes into an object.
 
@@ -174,6 +194,8 @@ def decode_json(  # type: ignore[misc]
         value: Value to decode
         target_type: An optional type to decode the data into
         type_decoders: Optional sequence of type decoders
+        strict: Whether type coercion rules should be strict. Setting to False enables
+            a wider set of coercion rules from string to non-string types for all values
 
     Returns:
         An object
@@ -185,7 +207,13 @@ def decode_json(  # type: ignore[misc]
         if target_type is Empty:
             return _msgspec_json_decoder.decode(value)
         return msgspec.json.decode(
-            value, dec_hook=partial(default_deserializer, type_decoders=type_decoders), type=target_type
+            value,
+            dec_hook=partial(
+                default_deserializer,
+                type_decoders=type_decoders,
+            ),
+            type=target_type,
+            strict=strict,
         )
     except msgspec.DecodeError as msgspec_error:
         raise SerializationException(str(msgspec_error)) from msgspec_error
@@ -213,29 +241,28 @@ def encode_msgpack(value: Any, serializer: Callable[[Any], Any] | None = default
 
 
 @overload
-def decode_msgpack(value: bytes) -> Any:
-    ...
+def decode_msgpack(value: bytes, strict: bool = ...) -> Any: ...
 
 
 @overload
-def decode_msgpack(value: bytes, type_decoders: TypeDecodersSequence | None) -> Any:
-    ...
+def decode_msgpack(value: bytes, type_decoders: TypeDecodersSequence | None, strict: bool = ...) -> Any: ...
 
 
 @overload
-def decode_msgpack(value: bytes, target_type: type[T]) -> T:
-    ...
+def decode_msgpack(value: bytes, target_type: type[T], strict: bool = ...) -> T: ...
 
 
 @overload
-def decode_msgpack(value: bytes, target_type: type[T], type_decoders: TypeDecodersSequence | None) -> T:
-    ...
+def decode_msgpack(
+    value: bytes, target_type: type[T], type_decoders: TypeDecodersSequence | None, strict: bool = ...
+) -> T: ...
 
 
 def decode_msgpack(  # type: ignore[misc]
     value: bytes,
     target_type: type[T] | EmptyType = Empty,  # pyright: ignore[reportInvalidTypeVarUse]
     type_decoders: TypeDecodersSequence | None = None,
+    strict: bool = True,
 ) -> Any:
     """Decode a MessagePack string/bytes into an object.
 
@@ -243,6 +270,8 @@ def decode_msgpack(  # type: ignore[misc]
         value: Value to decode
         target_type: An optional type to decode the data into
         type_decoders: Optional sequence of type decoders
+        strict: Whether type coercion rules should be strict. Setting to False enables
+            a wider set of coercion rules from string to non-string types for all values
 
     Returns:
         An object
@@ -254,7 +283,10 @@ def decode_msgpack(  # type: ignore[misc]
         if target_type is Empty:
             return _msgspec_msgpack_decoder.decode(value)
         return msgspec.msgpack.decode(
-            value, dec_hook=partial(default_deserializer, type_decoders=type_decoders), type=target_type
+            value,
+            dec_hook=partial(default_deserializer, type_decoders=type_decoders),
+            type=target_type,
+            strict=strict,
         )
     except msgspec.DecodeError as msgspec_error:
         raise SerializationException(str(msgspec_error)) from msgspec_error
