@@ -37,7 +37,7 @@ from typing import (
     cast,
 )
 
-from typing_extensions import Annotated, NotRequired, Required, get_args, get_origin, get_type_hints
+from typing_extensions import Annotated, NewType, NotRequired, Required, get_args, get_origin, get_type_hints
 
 from litestar.types.builtin_types import NoneType, UnionTypes
 
@@ -174,6 +174,14 @@ def unwrap_annotation(annotation: Any) -> tuple[Any, tuple[Any, ...], set[Any]]:
     return annotation, tuple(metadata), wrappers
 
 
+def unwrap_new_type(new_type: Any) -> Any:
+    """Unwrap a (nested) ``typing.NewType``"""
+    inner = new_type
+    while isinstance(inner, NewType):
+        inner = inner.__supertype__
+    return inner
+
+
 def get_origin_or_inner_type(annotation: Any) -> Any:
     """Get origin or unwrap it. Returns None for non-generic types.
 
@@ -262,6 +270,21 @@ def get_type_hints_with_generics_resolved(
     return {n: _substitute_typevars(type_, typevar_map) for n, type_ in type_hints.items()}
 
 
+def expand_type_var_in_type_hint(type_hint: dict[str, Any], namespace: dict[str, Any] | None) -> dict[str, Any]:
+    """Expand TypeVar for any parameters in type_hint
+
+    Args:
+        type_hint: mapping of parameter to type obtained from calling `get_type_hints` or `get_fn_type_hints`
+        namespace: mapping of TypeVar to concrete type
+
+    Returns:
+        type_hint with any TypeVar parameter expanded
+    """
+    if namespace:
+        return {name: _substitute_typevars(hint, namespace) for name, hint in type_hint.items()}
+    return type_hint
+
+
 def _substitute_typevars(obj: Any, typevar_map: Mapping[Any, Any]) -> Any:
     if params := getattr(obj, "__parameters__", None):
         args = tuple(_substitute_typevars(typevar_map.get(p, p), typevar_map) for p in params)
