@@ -3,22 +3,24 @@ from __future__ import annotations
 
 from dataclasses import dataclass, field
 from types import ModuleType
-from typing import TYPE_CHECKING, Callable, List, Optional
+from typing import TYPE_CHECKING, Callable, Dict, List, Optional
 from unittest.mock import MagicMock
 
 import pytest
-from msgspec import Struct, to_builtins
+from msgspec import Meta, Struct, to_builtins
 
 from litestar import Litestar, Request, get, post
 from litestar._openapi.schema_generation import SchemaCreator
 from litestar.dto import DataclassDTO, DTOConfig, DTOField
-from litestar.dto._backend import DTOBackend
+from litestar.dto._backend import DTOBackend, _create_struct_field_meta_for_field_definition
 from litestar.dto._types import CollectionType, SimpleType, TransferDTOFieldDefinition
 from litestar.dto.data_structures import DTOFieldDefinition
 from litestar.enums import MediaType
 from litestar.exceptions import SerializationException
+from litestar.openapi.spec.example import Example
 from litestar.openapi.spec.reference import Reference
 from litestar.openapi.spec.schema import Schema
+from litestar.params import KwargDefinition
 from litestar.serialization import encode_json
 from litestar.testing import RequestFactory
 from litestar.typing import FieldDefinition
@@ -38,6 +40,8 @@ class DC:
     a: int
     nested: NestedDC
     nested_list: List[NestedDC]
+    nested_mapping: Dict[str, NestedDC]
+    integer: int
     b: str = field(default="b")
     c: List[int] = field(default_factory=list)
     optional: Optional[str] = None
@@ -49,13 +53,23 @@ DESTRUCTURED = {
     "c": [],
     "nested": {"a": 1, "b": "two"},
     "nested_list": [{"a": 1, "b": "two"}],
+    "nested_mapping": {"a": {"a": 1, "b": "two"}},
+    "integer": 1,
     "optional": None,
 }
-RAW = b'{"a":1,"nested":{"a":1,"b":"two"},"nested_list":[{"a":1,"b":"two"}],"b":"b","c":[],"optional":null}'
-COLLECTION_RAW = (
-    b'[{"a":1,"nested":{"a":1,"b":"two"},"nested_list":[{"a":1,"b":"two"}],"b":"b","c":[],"optional":null}]'
+RAW = b'{"a":1,"nested":{"a":1,"b":"two"},"nested_list":[{"a":1,"b":"two"}],"nested_mapping":{"a":{"a":1,"b":"two"}},"integer":1,"b":"b","c":[],"optional":null}'
+MSGPACK_RAW = b"\x88\xa1a\x01\xa6nested\x82\xa1a\x01\xa1b\xa3two\xabnested_list\x91\x82\xa1a\x01\xa1b\xa3two\xaenested_mapping\x81\xa1a\x82\xa1a\x01\xa1b\xa3two\xa7integer\x01\xa1b\xa1b\xa1c\x90\xa8optional\xc0"
+COLLECTION_RAW = b'[{"a":1,"nested":{"a":1,"b":"two"},"nested_list":[{"a":1,"b":"two"}],"nested_mapping":{"a":{"a":1,"b":"two"}},"integer":1,"b":"b","c":[],"optional":null}]'
+STRUCTURED = DC(
+    a=1,
+    b="b",
+    c=[],
+    nested=NestedDC(a=1, b="two"),
+    nested_list=[NestedDC(a=1, b="two")],
+    nested_mapping={"a": NestedDC(a=1, b="two")},
+    optional=None,
+    integer=1,
 )
-STRUCTURED = DC(a=1, b="b", c=[], nested=NestedDC(a=1, b="two"), nested_list=[NestedDC(a=1, b="two")], optional=None)
 
 
 @pytest.fixture(name="dto_factory")
@@ -70,8 +84,7 @@ def fx_backend_factory(use_experimental_dto_backend: bool) -> type[DataclassDTO]
 @pytest.fixture(name="asgi_connection")
 def fx_asgi_connection() -> Request[Any, Any, Any]:
     @get("/", name="handler_id", media_type=MediaType.JSON)
-    def _handler() -> None:
-        ...
+    def _handler() -> None: ...
 
     return RequestFactory().get(path="/", route_handler=_handler)
 
@@ -88,7 +101,7 @@ def test_backend_parse_raw_json(
                 wrapper_attribute_name=None,
                 is_data_field=True,
                 handler_id="test",
-            ).parse_raw(b'{"a":1,"nested":{"a":1,"b":"two"},"nested_list":[{"a":1,"b":"two"}]}', asgi_connection)
+            ).parse_raw(RAW, asgi_connection)
         )
         == DESTRUCTURED
     )
@@ -96,8 +109,7 @@ def test_backend_parse_raw_json(
 
 def test_backend_parse_raw_msgpack(dto_factory: type[DataclassDTO], backend_cls: type[DTOBackend]) -> None:
     @get("/", name="handler_id", media_type=MediaType.MESSAGEPACK)
-    def _handler() -> None:
-        ...
+    def _handler() -> None: ...
 
     asgi_connection = RequestFactory().get(
         path="/", route_handler=_handler, headers={"Content-Type": MediaType.MESSAGEPACK}
@@ -111,10 +123,7 @@ def test_backend_parse_raw_msgpack(dto_factory: type[DataclassDTO], backend_cls:
                 wrapper_attribute_name=None,
                 is_data_field=True,
                 handler_id="test",
-            ).parse_raw(
-                b"\x83\xa1a\x01\xa6nested\x82\xa1a\x01\xa1b\xa3two\xabnested_list\x91\x82\xa1a\x01\xa1b\xa3two",
-                asgi_connection,
-            )
+            ).parse_raw(MSGPACK_RAW, asgi_connection)
         )
         == DESTRUCTURED
     )
@@ -124,8 +133,7 @@ def test_backend_parse_unsupported_media_type(
     dto_factory: type[DataclassDTO], asgi_connection: Request[Any, Any, Any], backend_cls: type[DTOBackend]
 ) -> None:
     @get("/", name="handler_id", media_type="text/css")
-    def _handler() -> None:
-        ...
+    def _handler() -> None: ...
 
     asgi_connection = RequestFactory().get(path="/", route_handler=_handler, headers={"Content-Type": "text/css"})
 
@@ -197,6 +205,7 @@ def test_backend_create_openapi_schema(dto_factory: type[DataclassDTO]) -> None:
     schemas = creator.schema_registry.generate_components_schemas()
     assert isinstance(ref, Reference)
     schema = schemas[ref.value]
+    assert schema.title == "HandlerDCResponseBody"
     assert schema.properties is not None
     a, b, c = schema.properties["a"], schema.properties["b"], schema.properties["c"]
     assert isinstance(a, Schema)
@@ -209,6 +218,7 @@ def test_backend_create_openapi_schema(dto_factory: type[DataclassDTO]) -> None:
     assert c.items.type == "integer"
     assert isinstance(nested := schema.properties["nested"], Reference)  # noqa: RUF018
     nested_schema = schemas[nested.value]
+    assert nested_schema.title == "HandlerDCNestedDCResponseBody"
     assert nested_schema.properties is not None
     nested_a, nested_b = nested_schema.properties["a"], nested_schema.properties["b"]
     assert isinstance(nested_a, Schema)
@@ -451,3 +461,29 @@ dto_type = DataclassDTO[Model]
     assert b_d_nested_info is not None
     assert not next(f for f in b_d_nested_info.field_definitions if f.name == "e").is_excluded
     assert b_d_nested_info.field_definitions[1].name == "f"
+
+
+@pytest.mark.parametrize(
+    ("constraint_kwargs",),
+    (
+        ({},),
+        ({"gt": 0, "lt": 2},),
+        ({"ge": 0, "le": 2},),
+        ({"min_length": 1, "max_length": 2},),
+        ({"pattern": "test"},),
+    ),
+)
+def test_create_struct_field_meta_for_field_definition(constraint_kwargs: Any) -> None:
+    mock_field = MagicMock(spec=TransferDTOFieldDefinition, is_partial=False)
+    mock_field.kwarg_definition = KwargDefinition(
+        description="test",
+        examples=[Example(value=1)],
+        title="test",
+        **constraint_kwargs,
+    )
+    assert _create_struct_field_meta_for_field_definition(mock_field) == Meta(
+        description="test",
+        examples=[1],
+        title="test",
+        **constraint_kwargs,
+    )
