@@ -51,18 +51,17 @@ async def form_multi_item_handler(request: Request) -> DefaultDict[str, list]:
     data = await request.form()
     output = defaultdict(list)
     for key, value in data.multi_items():
-        for v in value:
-            if isinstance(v, UploadFile):
-                content = await v.read()
-                output[key].append(
-                    {
-                        "filename": v.filename,
-                        "content": content.decode(),
-                        "content_type": v.content_type,
-                    }
-                )
-            else:
-                output[key].append(v)
+        if isinstance(value, UploadFile):
+            content = await value.read()
+            output[key].append(
+                {
+                    "filename": value.filename,
+                    "content": content.decode(),
+                    "content_type": value.content_type,
+                }
+            )
+        else:
+            output[key].append(value)
     return output
 
 
@@ -187,7 +186,11 @@ def test_multipart_request_multiple_files_with_headers(tmpdir: Any) -> None:
                 "filename": "test2.txt",
                 "content": "<file2 content>",
                 "content_type": "text/plain",
-                "headers": [["content-disposition", "form-data"], ["x-custom", "f2"], ["content-type", "text/plain"]],
+                "headers": [
+                    ["content-disposition", 'form-data; name="test2"; filename="test2.txt"'],
+                    ["x-custom", "f2"],
+                    ["content-type", "text/plain"],
+                ],
             },
         }
 
@@ -293,6 +296,7 @@ def test_multipart_request_without_charset_for_filename() -> None:
         }
 
 
+@pytest.mark.xfail(reason="filename* is deprecated and should not be used according to RFC-7578")
 def test_multipart_request_with_asterisks_filename() -> None:
     with create_test_client(form_handler) as client:
         response = client.post(
@@ -394,10 +398,15 @@ def test_image_upload() -> None:
         assert response.status_code == HTTP_201_CREATED
 
 
+@pytest.mark.parametrize("optional", [True, False])
 @pytest.mark.parametrize("file_count", (1, 2))
-def test_upload_multiple_files(file_count: int) -> None:
-    @post("/")
-    async def handler(data: List[UploadFile] = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:
+def test_upload_multiple_files(file_count: int, optional: bool) -> None:
+    annotation = List[UploadFile]
+    if optional:
+        annotation = Optional[annotation]  # type: ignore[misc, assignment]
+
+    @post("/", signature_namespace={"annotation": annotation})
+    async def handler(data: annotation = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:  # pyright: ignore[reportGeneralTypeIssues]
         assert len(data) == file_count
 
         for file in data:
@@ -415,13 +424,20 @@ class Files:
     file_list: List[UploadFile]
 
 
-@pytest.mark.parametrize("file_count", (1, 2))
-def test_upload_multiple_files_in_model(file_count: int) -> None:
-    @post("/")
-    async def handler(data: Files = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:
-        assert len(data.file_list) == file_count
+# https://github.com/litestar-org/litestar/issues/3407
+@dataclass
+class OptionalFiles:
+    file_list: Optional[List[UploadFile]]
 
-        for file in data.file_list:
+
+@pytest.mark.parametrize("file_model", (Files, OptionalFiles))
+@pytest.mark.parametrize("file_count", (1, 2))
+def test_upload_multiple_files_in_model(file_count: int, file_model: type[Files | OptionalFiles]) -> None:
+    @post("/", signature_namespace={"file_model": file_model})
+    async def handler(data: file_model = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:  # type: ignore[valid-type]
+        assert len(data.file_list) == file_count  # type: ignore[attr-defined]
+
+        for file in data.file_list:  # type: ignore[attr-defined]
             assert await file.read() == b"1"
 
     with create_test_client([handler]) as client:
@@ -445,13 +461,14 @@ def test_optional_formdata() -> None:
 @pytest.mark.parametrize("limit", (1000, 100, 10))
 def test_multipart_form_part_limit(limit: int) -> None:
     @post("/", signature_types=[UploadFile])
-    async def hello_world(data: List[UploadFile] = Body(media_type=RequestEncodingType.MULTI_PART)) -> None:
-        assert len(data) == limit
+    async def hello_world(data: List[UploadFile] = Body(media_type=RequestEncodingType.MULTI_PART)) -> dict:
+        return {"limit": len(data)}
 
     with create_test_client(route_handlers=[hello_world], multipart_form_part_limit=limit) as client:
         data = {str(i): "a" for i in range(limit)}
         response = client.post("/", files=data)
         assert response.status_code == HTTP_201_CREATED
+        assert response.json() == {"limit": limit}
 
         data = {str(i): "a" for i in range(limit)}
         data[str(limit + 1)] = "b"
@@ -566,3 +583,18 @@ def test_multipart_and_url_encoded_behave_the_same(form_type) -> None:  # type:
                 headers={"Content-Type": "multipart/form-data; boundary=1f35df74046888ceaa62d8a534a076dd"},
             )
         assert response.status_code == HTTP_201_CREATED
+
+
+def test_invalid_multipart_raises_client_error() -> None:
+    with create_test_client(form_handler) as client:
+        response = client.post(
+            "/form",
+            content=(
+                b"--20b303e711c4ab8c443184ac833ab00f\r\n"
+                b"Content-Disposition: form-data; "
+                b'name="value"\r\n\r\n'
+                b"--20b303e711c4ab8c44318833ab00f--\r\n"
+            ),
+            headers={"Content-Type": "multipart/form-data; charset=utf-8; boundary=20b303e711c4ab8c443184ac833ab00f"},
+        )
+        assert response.status_code == HTTP_400_BAD_REQUEST
