@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import dataclasses
 from dataclasses import dataclass
 from types import ModuleType
 from typing import Callable, Generic, Optional, TypeVar, cast
@@ -9,9 +10,8 @@ import pytest
 import yaml
 from typing_extensions import Annotated
 
-from litestar import Controller, Litestar, delete, get, patch, post
+from litestar import Controller, Litestar, Router, delete, get, patch, post
 from litestar._openapi.plugin import OpenAPIPlugin
-from litestar.app import DEFAULT_OPENAPI_CONFIG
 from litestar.enums import MediaType, OpenAPIMediaType, ParamType
 from litestar.openapi import OpenAPIConfig, OpenAPIController
 from litestar.openapi.spec import Parameter as OpenAPIParameter
@@ -23,12 +23,22 @@ from litestar.testing import create_test_client
 CREATE_EXAMPLES_VALUES = (True, False)
 
 
-@pytest.mark.parametrize("create_examples", CREATE_EXAMPLES_VALUES)
+@pytest.fixture(params=[True, False])
+def create_examples(request: pytest.FixtureRequest) -> bool:
+    return request.param  # type: ignore[no-any-return]
+
+
 @pytest.mark.parametrize("schema_path", ["/schema/openapi.yaml", "/schema/openapi.yml"])
 def test_openapi(
-    person_controller: type[Controller], pet_controller: type[Controller], create_examples: bool, schema_path: str
+    person_controller: type[Controller],
+    pet_controller: type[Controller],
+    create_examples: bool,
+    schema_path: str,
+    openapi_controller: type[OpenAPIController] | None,
 ) -> None:
-    openapi_config = OpenAPIConfig("Example API", "1.0.0", create_examples=create_examples)
+    openapi_config = OpenAPIConfig(
+        "Example API", "1.0.0", create_examples=create_examples, openapi_controller=openapi_controller
+    )
     with create_test_client([person_controller, pet_controller], openapi_config=openapi_config) as client:
         assert client.app.openapi_schema
         openapi_schema = client.app.openapi_schema
@@ -42,11 +52,15 @@ def test_openapi(
         assert response.content.decode("utf-8") == yaml.dump(schema_json)
 
 
-@pytest.mark.parametrize("create_examples", CREATE_EXAMPLES_VALUES)
 def test_openapi_json(
-    person_controller: type[Controller], pet_controller: type[Controller], create_examples: bool
+    person_controller: type[Controller],
+    pet_controller: type[Controller],
+    create_examples: bool,
+    openapi_controller: type[OpenAPIController] | None,
 ) -> None:
-    openapi_config = OpenAPIConfig("Example API", "1.0.0", create_examples=create_examples)
+    openapi_config = OpenAPIConfig(
+        "Example API", "1.0.0", create_examples=create_examples, openapi_controller=openapi_controller
+    )
     with create_test_client([person_controller, pet_controller], openapi_config=openapi_config) as client:
         assert client.app.openapi_schema
         openapi_schema = client.app.openapi_schema
@@ -63,10 +77,15 @@ def test_openapi_json(
     "endpoint, schema_path", [("openapi.yaml", "/schema/openapi.yaml"), ("openapi.yml", "/schema/openapi.yml")]
 )
 def test_openapi_yaml_not_allowed(
-    endpoint: str, schema_path: str, person_controller: type[Controller], pet_controller: type[Controller]
+    endpoint: str,
+    schema_path: str,
+    person_controller: type[Controller],
+    pet_controller: type[Controller],
+    openapi_controller: type[OpenAPIController] | None,
 ) -> None:
-    openapi_config = DEFAULT_OPENAPI_CONFIG
-    openapi_config.enabled_endpoints.discard(endpoint)
+    openapi_config = OpenAPIConfig(
+        "Example API", "1.0.0", enabled_endpoints=set(), openapi_controller=openapi_controller
+    )
 
     with create_test_client([person_controller, pet_controller], openapi_config=openapi_config) as client:
         assert client.app.openapi_schema
@@ -77,8 +96,13 @@ def test_openapi_yaml_not_allowed(
 
 
 def test_openapi_json_not_allowed(person_controller: type[Controller], pet_controller: type[Controller]) -> None:
-    openapi_config = DEFAULT_OPENAPI_CONFIG
-    openapi_config.enabled_endpoints.discard("openapi.json")
+    # only tested with the OpenAPIController, b/c new router based approach always serves `openapi.json`.
+    openapi_config = OpenAPIConfig(
+        "Example API",
+        "1.0.0",
+        enabled_endpoints=set(),
+        openapi_controller=OpenAPIController,
+    )
 
     with create_test_client([person_controller, pet_controller], openapi_config=openapi_config) as client:
         assert client.app.openapi_schema
@@ -88,8 +112,27 @@ def test_openapi_json_not_allowed(person_controller: type[Controller], pet_contr
         assert response.status_code == HTTP_404_NOT_FOUND
 
 
-def test_openapi_custom_path() -> None:
-    openapi_config = OpenAPIConfig(title="my title", version="1.0.0", path="/custom_schema_path")
+@pytest.mark.parametrize(
+    "schema_paths",
+    [
+        ("/schema/openapi.json", "/schema/openapi.yaml"),
+        ("/schema/openapi.yaml", "/schema/openapi.json"),
+    ],
+)
+def test_openapi_controller_internal_schema_conversion(schema_paths: list[str]) -> None:
+    openapi_config = OpenAPIConfig("Example API", "1.0.0", openapi_controller=OpenAPIController)
+
+    with create_test_client([], openapi_config=openapi_config) as client:
+        for schema_path in schema_paths:
+            response = client.get(schema_path)
+            assert response.status_code == HTTP_200_OK
+            assert "Example API" in response.text
+
+
+def test_openapi_custom_path(openapi_controller: type[OpenAPIController] | None) -> None:
+    openapi_config = OpenAPIConfig(
+        title="my title", version="1.0.0", path="/custom_schema_path", openapi_controller=openapi_controller
+    )
     with create_test_client([], openapi_config=openapi_config) as client:
         response = client.get("/schema")
         assert response.status_code == HTTP_404_NOT_FOUND
@@ -101,8 +144,10 @@ def test_openapi_custom_path() -> None:
         assert response.status_code == HTTP_200_OK
 
 
-def test_openapi_normalizes_custom_path() -> None:
-    openapi_config = OpenAPIConfig(title="my title", version="1.0.0", path="custom_schema_path")
+def test_openapi_normalizes_custom_path(openapi_controller: type[OpenAPIController] | None) -> None:
+    openapi_config = OpenAPIConfig(
+        title="my title", version="1.0.0", path="custom_schema_path", openapi_controller=openapi_controller
+    )
     with create_test_client([], openapi_config=openapi_config) as client:
         response = client.get("/custom_schema_path/openapi.json")
         assert response.status_code == HTTP_200_OK
@@ -145,8 +190,7 @@ def test_openapi_custom_path_overrides_custom_controller_path() -> None:
         assert response.status_code == HTTP_200_OK
 
 
-@pytest.mark.parametrize("create_examples", CREATE_EXAMPLES_VALUES)
-def test_msgspec_schema_generation(create_examples: bool) -> None:
+def test_msgspec_schema_generation(create_examples: bool, openapi_controller: type[OpenAPIController] | None) -> None:
     class Lookup(msgspec.Struct):
         id: Annotated[
             str,
@@ -168,6 +212,7 @@ def test_msgspec_schema_generation(create_examples: bool) -> None:
             title="Example API",
             version="1.0.0",
             create_examples=create_examples,
+            openapi_controller=openapi_controller,
         ),
         signature_types=[Lookup],
     ) as client:
@@ -177,14 +222,53 @@ def test_msgspec_schema_generation(create_examples: bool) -> None:
             "id"
         ] == {
             "description": "A unique identifier",
-            "examples": {"id-example-1": {"value": "e4eaaaf2-d142-11e1-b3e4-080027620cdd"}},
+            "examples": ["e4eaaaf2-d142-11e1-b3e4-080027620cdd"],
             "maxLength": 16,
             "minLength": 12,
             "type": "string",
         }
 
 
-def test_schema_for_optional_path_parameter() -> None:
+def test_dataclass_field_default() -> None:
+    # https://github.com/litestar-org/litestar/issues/3201
+    @dataclass
+    class SomeModel:
+        field_a: str = "default_a"
+        field_b: str = dataclasses.field(default="default_b")
+        field_c: str = dataclasses.field(default_factory=lambda: "default_c")
+
+    @get("/")
+    async def handler() -> SomeModel:
+        return SomeModel()
+
+    app = Litestar(route_handlers=[handler], signature_types=[SomeModel])
+    schema = app.openapi_schema.components.schemas["test_dataclass_field_default.SomeModel"]
+    assert schema
+    assert schema.properties["field_a"].default == "default_a"  # type: ignore[union-attr, index]
+    assert schema.properties["field_b"].default == "default_b"  # type: ignore[union-attr, index]
+    assert schema.properties["field_c"].default is None  # type: ignore[union-attr, index]
+
+
+def test_struct_field_default() -> None:
+    # https://github.com/litestar-org/litestar/issues/3201
+    class SomeModel(msgspec.Struct, kw_only=True):
+        field_a: str = "default_a"
+        field_b: str = msgspec.field(default="default_b")
+        field_c: str = msgspec.field(default_factory=lambda: "default_c")
+
+    @get("/")
+    async def handler() -> SomeModel:
+        return SomeModel()
+
+    app = Litestar(route_handlers=[handler], signature_types=[SomeModel])
+    schema = app.openapi_schema.components.schemas["test_struct_field_default.SomeModel"]
+    assert schema
+    assert schema.properties["field_a"].default == "default_a"  # type: ignore[union-attr, index]
+    assert schema.properties["field_b"].default == "default_b"  # type: ignore[union-attr, index]
+    assert schema.properties["field_c"].default is None  # type: ignore[union-attr, index]
+
+
+def test_schema_for_optional_path_parameter(openapi_controller: type[OpenAPIController] | None) -> None:
     @get(path=["/", "/{test_message:str}"], media_type=MediaType.TEXT, sync_to_thread=False)
     def handler(test_message: Optional[str]) -> str:  # noqa: UP007
         return test_message or "no message"
@@ -195,6 +279,7 @@ def test_schema_for_optional_path_parameter() -> None:
             title="Example API",
             version="1.0.0",
             create_examples=True,
+            openapi_controller=openapi_controller,
         ),
     ) as client:
         response = client.get("/schema/openapi.json")
@@ -214,7 +299,7 @@ class Foo(Generic[T]):
     foo: T
 
 
-def test_with_generic_class() -> None:
+def test_with_generic_class(openapi_controller: type[OpenAPIController] | None) -> None:
     @get("/foo-str", sync_to_thread=False)
     def handler_foo_str() -> Foo[str]:
         return Foo("")
@@ -228,6 +313,7 @@ def test_with_generic_class() -> None:
         openapi_config=OpenAPIConfig(
             title="Example API",
             version="1.0.0",
+            openapi_controller=openapi_controller,
         ),
     ) as client:
         response = client.get("/schema/openapi.json")
@@ -245,7 +331,7 @@ def test_with_generic_class() -> None:
                             "200": {
                                 "description": "Request fulfilled, document follows",
                                 "headers": {},
-                                "content": {"application/json": {"schema": {"$ref": "#/components/schemas/Foo[str]"}}},
+                                "content": {"application/json": {"schema": {"$ref": "#/components/schemas/Foo_str_"}}},
                             }
                         },
                         "deprecated": False,
@@ -259,7 +345,7 @@ def test_with_generic_class() -> None:
                             "200": {
                                 "description": "Request fulfilled, document follows",
                                 "headers": {},
-                                "content": {"application/json": {"schema": {"$ref": "#/components/schemas/Foo[int]"}}},
+                                "content": {"application/json": {"schema": {"$ref": "#/components/schemas/Foo_int_"}}},
                             }
                         },
                         "deprecated": False,
@@ -268,13 +354,13 @@ def test_with_generic_class() -> None:
             },
             "components": {
                 "schemas": {
-                    "Foo[str]": {
+                    "Foo_str_": {
                         "properties": {"foo": {"type": "string"}},
                         "type": "object",
                         "required": ["foo"],
                         "title": "Foo[str]",
                     },
-                    "Foo[int]": {
+                    "Foo_int_": {
                         "properties": {"foo": {"type": "integer"}},
                         "type": "object",
                         "required": ["foo"],
@@ -356,12 +442,10 @@ class Model:
 
 def test_multiple_handlers_for_same_route() -> None:
     @post("/", sync_to_thread=False)
-    def post_handler() -> None:
-        ...
+    def post_handler() -> None: ...
 
     @get("/", sync_to_thread=False)
-    def get_handler() -> None:
-        ...
+    def get_handler() -> None: ...
 
     app = Litestar([get_handler, post_handler])
     openapi_plugin = app.plugins.get(OpenAPIPlugin)
@@ -376,12 +460,10 @@ def test_multiple_handlers_for_same_route() -> None:
 @pytest.mark.parametrize(("random_seed_one", "random_seed_two", "should_be_equal"), [(10, 10, True), (10, 20, False)])
 def test_seeding(random_seed_one: int, random_seed_two: int, should_be_equal: bool) -> None:
     @post("/", sync_to_thread=False)
-    def post_handler(q: str) -> None:
-        ...
+    def post_handler(q: str) -> None: ...
 
     @get("/", sync_to_thread=False)
-    def get_handler(q: str) -> None:
-        ...
+    def get_handler(q: str) -> None: ...
 
     app = Litestar(
         [get_handler, post_handler], openapi_config=OpenAPIConfig("Litestar", "v0.0.1", True, random_seed_one)
@@ -405,21 +487,17 @@ def test_components_schemas_in_alphabetical_order() -> None:
     # https://github.com/litestar-org/litestar/issues/3059
 
     @dataclass
-    class A:
-        ...
+    class A: ...
 
     @dataclass
-    class B:
-        ...
+    class B: ...
 
     @dataclass
-    class C:
-        ...
+    class C: ...
 
     class TestController(Controller):
         @post("/", sync_to_thread=False)
-        def post_handler(self, data: B) -> None:
-            ...
+        def post_handler(self, data: B) -> None: ...
 
         @get("/", sync_to_thread=False)
         def get_handler(self) -> A:  # type: ignore[empty-body]
@@ -430,8 +508,7 @@ def test_components_schemas_in_alphabetical_order() -> None:
             ...
 
         @delete("/", sync_to_thread=False)
-        def delete_handler(self, data: B) -> None:
-            ...
+        def delete_handler(self, data: B) -> None: ...
 
     app = Litestar([TestController], signature_types=[A, B, C])
     openapi_plugin = app.plugins.get(OpenAPIPlugin)
@@ -443,3 +520,40 @@ def test_components_schemas_in_alphabetical_order() -> None:
         "test_components_schemas_in_alphabetical_order.C",
     ]
     assert list(openapi.components.schemas.keys()) == expected_keys
+
+
+def test_openapi_controller_and_openapi_router_on_same_app() -> None:
+    """Test that OpenAPIController and OpenAPIRouter can coexist on the same app.
+
+    As part of backward compatibility with new plugin-based OpenAPI router approach, we did not consider
+    the case where an OpenAPIController is registered on the application by means other than via the
+    OpenAPIConfig object. This is an approach that has been used to serve the openapi both under the
+    `/schema` and `/some-prefix/schema` paths. This test ensures that the OpenAPIController and OpenAPIRouter
+    can coexist on the same app.
+
+    See: https://github.com/litestar-org/litestar/issues/3337
+    """
+    router = Router(path="/abc", route_handlers=[OpenAPIController])
+    openapi_config = OpenAPIConfig("Litestar", "v0.0.1")  # no openapi_controller specified means we use the router
+    app = Litestar([router], openapi_config=openapi_config)
+    assert sorted(r.path for r in app.routes) == [
+        "/abc/schema",
+        "/abc/schema/elements",
+        "/abc/schema/oauth2-redirect.html",
+        "/abc/schema/openapi.json",
+        "/abc/schema/openapi.yaml",
+        "/abc/schema/openapi.yml",
+        "/abc/schema/rapidoc",
+        "/abc/schema/redoc",
+        "/abc/schema/swagger",
+        "/schema",
+        "/schema/elements",
+        "/schema/oauth2-redirect.html",
+        "/schema/openapi.json",
+        "/schema/openapi.yaml",
+        "/schema/openapi.yml",
+        "/schema/rapidoc",
+        "/schema/redoc",
+        "/schema/swagger",
+        "/schema/{path:str}",
+    ]
