@@ -1,8 +1,8 @@
 import sys
 from dataclasses import dataclass
-from datetime import date, datetime
+from datetime import date, datetime, timezone
 from enum import Enum, auto
-from typing import (  # type: ignore[attr-defined]
+from typing import (
     TYPE_CHECKING,
     Any,
     Dict,
@@ -13,33 +13,32 @@ from typing import (  # type: ignore[attr-defined]
     Tuple,
     TypedDict,
     TypeVar,
-    Union,
-    _GenericAlias,  # pyright: ignore
+    Union,  # pyright: ignore
 )
 
 import annotated_types
 import msgspec
 import pytest
 from msgspec import Struct
-from typing_extensions import Annotated, TypeAlias
+from typing_extensions import Annotated, TypeAlias, TypeAliasType
 
-from litestar import Controller, MediaType, get
+from litestar import Controller, MediaType, get, post
 from litestar._openapi.schema_generation.plugins import openapi_schema_plugins
 from litestar._openapi.schema_generation.schema import (
     KWARG_DEFINITION_ATTRIBUTE_TO_OPENAPI_PROPERTY_MAP,
     SchemaCreator,
 )
-from litestar._openapi.schema_generation.utils import _get_normalized_schema_key, _type_or_first_not_none_inner_type
-from litestar.app import DEFAULT_OPENAPI_CONFIG
+from litestar.app import DEFAULT_OPENAPI_CONFIG, Litestar
 from litestar.di import Provide
 from litestar.enums import ParamType
+from litestar.exceptions import ImproperlyConfiguredException
 from litestar.openapi.spec import ExternalDocumentation, OpenAPIType, Reference
 from litestar.openapi.spec.example import Example
+from litestar.openapi.spec.parameter import Parameter as OpenAPIParameter
 from litestar.openapi.spec.schema import Schema
 from litestar.pagination import ClassicPagination, CursorPagination, OffsetPagination
-from litestar.params import Parameter, ParameterKwarg
+from litestar.params import KwargDefinition, Parameter, ParameterKwarg
 from litestar.testing import create_test_client
-from litestar.types.builtin_types import NoneType
 from litestar.typing import FieldDefinition
 from litestar.utils.helpers import get_name
 from tests.helpers import get_schema_for_field_definition
@@ -82,63 +81,73 @@ def test_process_schema_result() -> None:
     assert kwarg_definition.examples
     for signature_key, schema_key in KWARG_DEFINITION_ATTRIBUTE_TO_OPENAPI_PROPERTY_MAP.items():
         if schema_key == "examples":
-            assert schema.examples == {"str-example-1": kwarg_definition.examples[0]}
+            assert schema.examples == [kwarg_definition.examples[0].value]
         else:
             assert getattr(schema, schema_key) == getattr(kwarg_definition, signature_key)
 
 
-def test_get_normalized_schema_key() -> None:
-    class LocalClass(msgspec.Struct):
-        id: str
-
-    # replace each of the long strings with underscores with a tuple of strings split at each underscore
-    assert (
-        "tests",
-        "unit",
-        "test_openapi",
-        "test_schema",
-        "test_get_normalized_schema_key.LocalClass",
-    ) == _get_normalized_schema_key(LocalClass)
-
-    assert ("tests", "models", "DataclassPerson") == _get_normalized_schema_key(DataclassPerson)
-
-    builtin_dict = Dict[str, List[int]]
-    assert ("typing", "Dict[str, typing.List[int]]") == _get_normalized_schema_key(builtin_dict)
-
-    builtin_with_custom = Dict[str, DataclassPerson]
-    assert ("typing", "Dict[str, tests.models.DataclassPerson]") == _get_normalized_schema_key(builtin_with_custom)
-
-    class LocalGeneric(Generic[T]):
+def test_override_schema_component_key() -> None:
+    @dataclass
+    class Data:
         pass
 
-    assert (
-        "tests",
-        "unit",
-        "test_openapi",
-        "test_schema",
-        "test_get_normalized_schema_key.LocalGeneric",
-    ) == _get_normalized_schema_key(LocalGeneric)
+    @post("/")
+    def handler(
+        data: Data,
+    ) -> Annotated[Data, Parameter(schema_component_key="not_data")]:
+        return Data()
 
-    generic_int = LocalGeneric[int]
-    generic_str = LocalGeneric[str]
+    @get("/")
+    def handler_2() -> Annotated[Data, Parameter(schema_component_key="not_data")]:
+        return Data()
 
-    assert (
-        "tests",
-        "unit",
-        "test_openapi",
-        "test_schema",
-        "test_get_normalized_schema_key.LocalGeneric[int]",
-    ) == _get_normalized_schema_key(generic_int)
+    app = Litestar([handler, handler_2])
+    schema = app.openapi_schema.to_schema()
+    # we expect the annotated / non-annotated to generate independent components
+    assert schema["paths"]["/"]["post"]["requestBody"]["content"]["application/json"] == {
+        "schema": {"$ref": "#/components/schemas/test_override_schema_component_key.Data"}
+    }
+    assert schema["paths"]["/"]["post"]["responses"]["201"]["content"] == {
+        "application/json": {"schema": {"$ref": "#/components/schemas/not_data"}}
+    }
+    # a response with the same type and the same name should reference the same component
+    assert schema["paths"]["/"]["get"]["responses"]["200"]["content"] == {
+        "application/json": {"schema": {"$ref": "#/components/schemas/not_data"}}
+    }
+    assert app.openapi_schema.to_schema()["components"] == {
+        "schemas": {
+            "not_data": {"properties": {}, "type": "object", "required": [], "title": "Data"},
+            "test_override_schema_component_key.Data": {
+                "properties": {},
+                "type": "object",
+                "required": [],
+                "title": "Data",
+            },
+        }
+    }
 
-    assert (
-        "tests",
-        "unit",
-        "test_openapi",
-        "test_schema",
-        "test_get_normalized_schema_key.LocalGeneric[str]",
-    ) == _get_normalized_schema_key(generic_str)
 
-    assert _get_normalized_schema_key(generic_int) != _get_normalized_schema_key(generic_str)
+def test_override_schema_component_key_raise_if_keys_are_not_unique() -> None:
+    @dataclass
+    class Data:
+        pass
+
+    @dataclass
+    class Data2:
+        pass
+
+    @post("/")
+    def handler(
+        data: Data,
+    ) -> Annotated[Data, Parameter(schema_component_key="not_data")]:
+        return Data()
+
+    @get("/")
+    def handler_2() -> Annotated[Data2, Parameter(schema_component_key="not_data")]:
+        return Data2()
+
+    with pytest.raises(ImproperlyConfiguredException, match="Schema component keys must be unique"):
+        Litestar([handler, handler_2]).openapi_schema.to_schema()
 
 
 def test_dependency_schema_generation() -> None:
@@ -225,7 +234,7 @@ def test_schema_hashing() -> None:
             Schema(type=OpenAPIType.NUMBER),
             Schema(type=OpenAPIType.OBJECT, properties={"key": Schema(type=OpenAPIType.STRING)}),
         ],
-        examples={"example-1": Example(value=None), "example-2": Example(value=[1, 2, 3])},
+        examples=[None, [1, 2, 3]],
     )
     assert hash(schema)
 
@@ -284,16 +293,27 @@ class Foo(TypedDict):
 
 def test_create_schema_from_msgspec_annotated_type() -> None:
     class Lookup(msgspec.Struct):
-        id: Annotated[str, msgspec.Meta(max_length=16, examples=["example"], description="description", title="title")]
+        str_field: Annotated[
+            str,
+            msgspec.Meta(max_length=16, examples=["example"], description="description", title="title", pattern=r"\w+"),
+        ]
+        bytes_field: Annotated[bytes, msgspec.Meta(max_length=2, min_length=1)]
+        default_field: Annotated[str, msgspec.Meta(min_length=1)] = "a"
 
     schema = get_schema_for_field_definition(FieldDefinition.from_kwarg(name="Lookup", annotation=Lookup))
 
-    assert schema.properties["id"].type == OpenAPIType.STRING  # type: ignore[index, union-attr]
-    assert schema.properties["id"].examples == {"id-example-1": Example(value="example")}  # type: ignore[index, union-attr]
-    assert schema.properties["id"].description == "description"  # type: ignore[index]
-    assert schema.properties["id"].title == "title"  # type: ignore[index, union-attr]
-    assert schema.properties["id"].max_length == 16  # type: ignore[index, union-attr]
-    assert schema.required == ["id"]
+    assert schema.properties["str_field"].type == OpenAPIType.STRING  # type: ignore[index, union-attr]
+    assert schema.properties["str_field"].examples == ["example"]  # type: ignore[index, union-attr]
+    assert schema.properties["str_field"].description == "description"  # type: ignore[index]
+    assert schema.properties["str_field"].title == "title"  # type: ignore[index, union-attr]
+    assert schema.properties["str_field"].max_length == 16  # type: ignore[index, union-attr]
+    assert sorted(schema.required) == sorted(["str_field", "bytes_field"])  # type: ignore[arg-type]
+    assert schema.properties["bytes_field"].to_schema() == {  # type: ignore[index]
+        "contentEncoding": "utf-8",
+        "maxLength": 2,
+        "minLength": 1,
+        "type": "string",
+    }
 
 
 def test_annotated_types() -> None:
@@ -305,10 +325,10 @@ def test_annotated_types() -> None:
         constrained_int: Annotated[int, annotated_types.Gt(1), annotated_types.Lt(10)]
         constrained_float: Annotated[float, annotated_types.Ge(1), annotated_types.Le(10)]
         constrained_date: Annotated[date, annotated_types.Interval(gt=historical_date, lt=today)]
-        constrained_lower_case: Annotated[str, annotated_types.LowerCase]
-        constrained_upper_case: Annotated[str, annotated_types.UpperCase]
-        constrained_is_ascii: Annotated[str, annotated_types.IsAscii]
-        constrained_is_digit: Annotated[str, annotated_types.IsDigits]
+        constrained_lower_case: annotated_types.LowerCase[str]
+        constrained_upper_case: annotated_types.UpperCase[str]
+        constrained_is_ascii: annotated_types.IsAscii[str]
+        constrained_is_digit: annotated_types.IsDigit[str]
 
     schema = get_schema_for_field_definition(FieldDefinition.from_kwarg(name="MyDataclass", annotation=MyDataclass))
 
@@ -316,12 +336,14 @@ def test_annotated_types() -> None:
     assert schema.properties["constrained_int"].exclusive_maximum == 10  # type: ignore[index, union-attr]
     assert schema.properties["constrained_float"].minimum == 1  # type: ignore[index, union-attr]
     assert schema.properties["constrained_float"].maximum == 10  # type: ignore[index, union-attr]
-    assert datetime.utcfromtimestamp(schema.properties["constrained_date"].exclusive_minimum) == datetime.fromordinal(  # type: ignore[arg-type, index, union-attr]
-        historical_date.toordinal()
-    )
-    assert datetime.utcfromtimestamp(schema.properties["constrained_date"].exclusive_maximum) == datetime.fromordinal(  # type: ignore[arg-type, index, union-attr]
-        today.toordinal()
-    )
+    assert datetime.fromtimestamp(
+        schema.properties["constrained_date"].exclusive_minimum,  # type: ignore[arg-type, index, union-attr]
+        tz=timezone.utc,
+    ) == datetime.fromordinal(historical_date.toordinal()).replace(tzinfo=timezone.utc)
+    assert datetime.fromtimestamp(
+        schema.properties["constrained_date"].exclusive_maximum,  # type: ignore[arg-type, index, union-attr]
+        tz=timezone.utc,
+    ) == datetime.fromordinal(today.toordinal()).replace(tzinfo=timezone.utc)
     assert schema.properties["constrained_lower_case"].description == "must be in lower case"  # type: ignore[index]
     assert schema.properties["constrained_upper_case"].description == "must be in upper case"  # type: ignore[index]
     assert schema.properties["constrained_is_ascii"].pattern == "[[:ascii:]]"  # type: ignore[index, union-attr]
@@ -367,7 +389,7 @@ if sys.version_info >= (3, 11):
 @pytest.mark.parametrize("cls", annotations)
 def test_schema_generation_with_generic_classes(cls: Any) -> None:
     expected_foo_schema = Schema(type=OpenAPIType.INTEGER)
-    expected_optional_foo_schema = Schema(one_of=[Schema(type=OpenAPIType.NULL), Schema(type=OpenAPIType.INTEGER)])
+    expected_optional_foo_schema = Schema(one_of=[Schema(type=OpenAPIType.INTEGER), Schema(type=OpenAPIType.NULL)])
 
     properties = get_schema_for_field_definition(
         FieldDefinition.from_kwarg(name=get_name(cls), annotation=cls)
@@ -421,7 +443,7 @@ def test_schema_generation_with_generic_classes_constrained() -> None:
 )
 def test_schema_generation_with_pagination(annotation: Any) -> None:
     expected_foo_schema = Schema(type=OpenAPIType.INTEGER)
-    expected_optional_foo_schema = Schema(one_of=[Schema(type=OpenAPIType.NULL), Schema(type=OpenAPIType.INTEGER)])
+    expected_optional_foo_schema = Schema(one_of=[Schema(type=OpenAPIType.INTEGER), Schema(type=OpenAPIType.NULL)])
 
     properties = get_schema_for_field_definition(FieldDefinition.from_annotation(annotation).inner_types[-1]).properties
 
@@ -448,13 +470,87 @@ def test_schema_tuple_with_union() -> None:
 
 def test_optional_enum() -> None:
     class Foo(Enum):
+        A = 1
+        B = "b"
+
+    creator = SchemaCreator(plugins=openapi_schema_plugins)
+    schema = creator.for_field_definition(FieldDefinition.from_annotation(Optional[Foo]))
+    assert isinstance(schema, Schema)
+    assert schema.type is None
+    assert schema.one_of is not None
+    null_schema = schema.one_of[1]
+    assert isinstance(null_schema, Schema)
+    assert null_schema.type is not None
+    assert null_schema.type is OpenAPIType.NULL
+    enum_ref = schema.one_of[0]
+    assert isinstance(enum_ref, Reference)
+    assert enum_ref.ref == "#/components/schemas/tests_unit_test_openapi_test_schema_test_optional_enum.Foo"
+    enum_schema = creator.schema_registry.from_reference(enum_ref).schema
+    assert enum_schema.type
+    assert set(enum_schema.type) == {OpenAPIType.INTEGER, OpenAPIType.STRING}
+    assert enum_schema.enum
+    assert enum_schema.enum[0] == 1
+    assert enum_schema.enum[1] == "b"
+
+
+def test_optional_str_specified_enum() -> None:
+    class StringEnum(str, Enum):
+        A = "a"
+        B = "b"
+
+    creator = SchemaCreator(plugins=openapi_schema_plugins)
+    schema = creator.for_field_definition(FieldDefinition.from_annotation(Optional[StringEnum]))
+    assert isinstance(schema, Schema)
+    assert schema.type is None
+    assert schema.one_of is not None
+
+    enum_ref = schema.one_of[0]
+    assert isinstance(enum_ref, Reference)
+    assert (
+        enum_ref.ref
+        == "#/components/schemas/tests_unit_test_openapi_test_schema_test_optional_str_specified_enum.StringEnum"
+    )
+    enum_schema = creator.schema_registry.from_reference(enum_ref).schema
+    assert enum_schema.type
+    assert enum_schema.type == OpenAPIType.STRING
+    assert enum_schema.enum
+    assert enum_schema.enum[0] == "a"
+    assert enum_schema.enum[1] == "b"
+
+    null_schema = schema.one_of[1]
+    assert isinstance(null_schema, Schema)
+    assert null_schema.type is not None
+    assert null_schema.type is OpenAPIType.NULL
+
+
+def test_optional_int_specified_enum() -> None:
+    class IntEnum(int, Enum):
         A = 1
         B = 2
 
-    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(Optional[Foo]))
-    assert schema.type is not None
-    assert set(schema.type) == {OpenAPIType.INTEGER, OpenAPIType.NULL}
-    assert schema.enum == [1, 2, None]
+    creator = SchemaCreator(plugins=openapi_schema_plugins)
+    schema = creator.for_field_definition(FieldDefinition.from_annotation(Optional[IntEnum]))
+    assert isinstance(schema, Schema)
+    assert schema.type is None
+    assert schema.one_of is not None
+
+    enum_ref = schema.one_of[0]
+    assert isinstance(enum_ref, Reference)
+    assert (
+        enum_ref.ref
+        == "#/components/schemas/tests_unit_test_openapi_test_schema_test_optional_int_specified_enum.IntEnum"
+    )
+    enum_schema = creator.schema_registry.from_reference(enum_ref).schema
+    assert enum_schema.type
+    assert enum_schema.type == OpenAPIType.INTEGER
+    assert enum_schema.enum
+    assert enum_schema.enum[0] == 1
+    assert enum_schema.enum[1] == 2
+
+    null_schema = schema.one_of[1]
+    assert isinstance(null_schema, Schema)
+    assert null_schema.type is not None
+    assert null_schema.type is OpenAPIType.NULL
 
 
 def test_optional_literal() -> None:
@@ -464,24 +560,6 @@ def test_optional_literal() -> None:
     assert schema.enum == [1, None]
 
 
-@pytest.mark.parametrize(
-    ("in_type", "out_type"),
-    [
-        (FieldDefinition.from_annotation(Optional[int]), int),
-        (FieldDefinition.from_annotation(Union[None, int]), int),
-        (FieldDefinition.from_annotation(int), int),
-        # hack to create a union of NoneType, NoneType to hit a branch for coverage
-        (FieldDefinition.from_annotation(_GenericAlias(Union, (NoneType, NoneType))), ValueError),
-    ],
-)
-def test_type_or_first_not_none_inner_type_utility(in_type: Any, out_type: Any) -> None:
-    if out_type is ValueError:
-        with pytest.raises(out_type):
-            _type_or_first_not_none_inner_type(in_type)
-    else:
-        assert _type_or_first_not_none_inner_type(in_type) == out_type
-
-
 def test_not_generating_examples_property() -> None:
     with_examples = SchemaCreator(generate_examples=True)
     without_examples = with_examples.not_generating_examples
@@ -499,7 +577,7 @@ def test_process_schema_result_with_unregistered_object_schema() -> None:
 
 @pytest.mark.parametrize("base_type", [msgspec.Struct, TypedDict, dataclass])
 def test_type_union(base_type: type) -> None:
-    if base_type is dataclass:  # type: ignore[comparison-overlap]
+    if base_type is dataclass:
 
         @dataclass
         class ModelA:  # pyright: ignore
@@ -529,7 +607,7 @@ def test_type_union(base_type: type) -> None:
 @pytest.mark.parametrize("base_type", [msgspec.Struct, TypedDict, dataclass])
 def test_type_union_with_none(base_type: type) -> None:
     # https://github.com/litestar-org/litestar/issues/2971
-    if base_type is dataclass:  # type: ignore[comparison-overlap]
+    if base_type is dataclass:
 
         @dataclass
         class ModelA:  # pyright: ignore
@@ -551,7 +629,93 @@ def test_type_union_with_none(base_type: type) -> None:
         FieldDefinition.from_kwarg(name="Lookup", annotation=Union[ModelA, ModelB, None])
     )
     assert schema.one_of == [
-        Schema(type=OpenAPIType.NULL),
         Reference(ref="#/components/schemas/tests_unit_test_openapi_test_schema_test_type_union_with_none.ModelA"),
         Reference("#/components/schemas/tests_unit_test_openapi_test_schema_test_type_union_with_none.ModelB"),
+        Schema(type=OpenAPIType.NULL),
     ]
+
+
+def test_default_only_on_field_definition() -> None:
+    field_definition = FieldDefinition.from_annotation(int, default=10)
+    assert field_definition.kwarg_definition is None
+
+    schema = get_schema_for_field_definition(field_definition)
+    assert schema.default == 10
+
+
+def test_default_not_provided_for_kwarg_but_for_field() -> None:
+    field_definition = FieldDefinition.from_annotation(int, default=10, kwarg_definition=KwargDefinition())
+    schema = get_schema_for_field_definition(field_definition)
+
+    assert schema.default == 10
+
+
+def test_routes_with_different_path_param_types_get_merged() -> None:
+    # https://github.com/litestar-org/litestar/issues/2700
+    @get("/{param:int}")
+    async def get_handler(param: int) -> None:
+        pass
+
+    @post("/{param:str}")
+    async def post_handler(param: str) -> None:
+        pass
+
+    app = Litestar([get_handler, post_handler])
+    assert app.openapi_schema.paths
+    paths = app.openapi_schema.paths["/{param}"]
+    assert paths.get is not None
+    assert paths.post is not None
+
+
+def test_unconsumed_path_parameters_are_documented() -> None:
+    # https://github.com/litestar-org/litestar/issues/3290
+    # https://github.com/litestar-org/litestar/issues/3369
+
+    async def dd(param3: Annotated[str, Parameter(description="123")]) -> str:
+        return param3
+
+    async def d(dep_dep: str, param2: Annotated[str, Parameter(description="abc")]) -> str:
+        return f"{dep_dep}_{param2}"
+
+    @get("/{param1:str}/{param2:str}/{param3:str}", dependencies={"dep": d, "dep_dep": dd})
+    async def handler(dep: str) -> None:
+        pass
+
+    app = Litestar([handler])
+    params = app.openapi_schema.paths["/{param1}/{param2}/{param3}"].get.parameters  # type: ignore[index, union-attr]
+    assert params
+    assert len(params) == 3
+    for i, param in enumerate(sorted(params, key=lambda p: p.name), 1):  # pyright: ignore
+        assert isinstance(param, OpenAPIParameter)
+        assert param.name == f"param{i}"
+        assert param.required is True
+        assert param.param_in is ParamType.PATH
+
+
+def test_type_alias_type() -> None:
+    @get("/")
+    def handler(query_param: Annotated[TypeAliasType("IntAlias", int), Parameter(description="foo")]) -> None:  # type: ignore[valid-type]
+        pass
+
+    app = Litestar([handler])
+    param = app.openapi_schema.paths["/"].get.parameters[0]  # type: ignore[index, union-attr]
+    assert param.schema.type is OpenAPIType.INTEGER  # type: ignore[union-attr]
+    # ensure other attributes than the plain type are carried over correctly
+    assert param.description == "foo"
+
+
+@pytest.mark.skipif(sys.version_info < (3, 12), reason="type keyword not available before 3.12")
+def test_type_alias_type_keyword() -> None:
+    ctx: Dict[str, Any] = {}
+    exec("type IntAlias = int", ctx, None)
+    annotation = ctx["IntAlias"]
+
+    @get("/")
+    def handler(query_param: Annotated[annotation, Parameter(description="foo")]) -> None:  # type: ignore[valid-type]
+        pass
+
+    app = Litestar([handler])
+    param = app.openapi_schema.paths["/"].get.parameters[0]  # type: ignore[union-attr, index]
+    assert param.schema.type is OpenAPIType.INTEGER  # type: ignore[union-attr]
+    # ensure other attributes than the plain type are carried over correctly
+    assert param.description == "foo"
