@@ -27,8 +27,7 @@ def test_resolve_type_encoders() -> None:
         type_encoders = {controller_type: controller_encoder}
 
         @get("/", type_encoders={handler_type: handler_encoder})
-        def handler(self) -> Any:
-            ...
+        def handler(self) -> Any: ...
 
     router = Router("/router", type_encoders={router_type: router_encoder}, route_handlers=[MyController])
     app = Litestar([router], type_encoders={app_type: app_encoder})
